@@ -26,14 +26,14 @@ static void finalize_welcome(void) {
 		tangle_actor_hide_animated(TANGLE_ACTOR(actor));
 	}
 
-	//Do not go to main-menu, but login_screen
+	#ifndef SKIP_LOGIN
 	login_screen();
-	/*
+	#else
 	if ((actor = jammo_get_actor_by_id("main-menu-view"))) {
 		clutter_actor_show(actor);
 		clutter_actor_queue_relayout(clutter_actor_get_parent(actor));
 	}
-	*/
+	#endif
 
 	//Set default language for singing game
 	// It also affects first flag showed
