@@ -8,9 +8,10 @@ This file contains the functionality of the avatar editor.
 #define AVATAR_EDITOR_H
 
 #include <tangle.h>
+#include "community_utilities.h"
 
 void start_avatar_editor();
-void set_avatar();
+void set_avatar(Avatar*, ClutterActor*, ClutterActor*, char*);
 void avatar_goto_communitymenu(TangleButton *tanglebutton, gpointer none);
 void avatar_goto_startmenu(TangleButton *tanglebutton, gpointer none);
 void change_body_color();
