@@ -23,6 +23,7 @@ Cancel-button returns without modification.
 #include "../file_helper.h"
 #include "sequencer.h"
 #include <string.h>
+#include "../../cem/cem.h"
 
 //Only one of these can be toggled down at a time.
 static gboolean vocal_selected = FALSE;
@@ -31,13 +32,15 @@ static gboolean melodic_selected = FALSE;
 static gchar* last_played_filename=NULL;
 static gchar* image_name_for_last_played=NULL;
 static GList* visible_borders = NULL; //Actors for frames surrounding selected image
-
+static ClutterActor* static_backingtrack = NULL; // When coming to backingtrack_selection this should be set.
 
 static JammoSequencer* adhoc_sequencer=NULL;
 static void on_sequencer_stopped(JammoSequencer* sequencer, gpointer user_data) {
-	printf("backingtrack_selection.c: on_sequencer_stopped\n");
-	g_object_unref(sequencer);
-	adhoc_sequencer=NULL;
+	cem_add_to_log("Backintrack-selection: preview song listened to end",J_LOG_INFO);
+	/*Nothing to really do.
+	If user selects next song this adhoc_sequencer is freed.
+	If user closes backingtrack_selection adhoc_sequencer is freed.
+	*/
 }
 
 
@@ -57,9 +60,15 @@ static void clear_list_and_make_new(){
 	visible_borders = NULL; //make new
 }
 
+void backingtrack_selection_set_track_view(ClutterActor* actor){
+	static_backingtrack = actor;
+}
+
 void backingtrack_song_clicked (TangleButton* tanglebutton, gpointer none){
 	const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton));
-	printf("backingtrack_song_clicked: '%s'\n",name);
+	gchar* message = g_strdup_printf("Backintrack-selection: Song '%s' clicked",name);
+	cem_add_to_log(message,J_LOG_USER_ACTION);
+	g_free(message);
 	//Remove and add frames for selected.
 	clear_list_and_make_new(); //for visible_borders
 	ClutterActor* actor = tangle_button_get_normal_background_actor(tanglebutton);
@@ -103,9 +112,13 @@ void backingtrack_song_clicked (TangleButton* tanglebutton, gpointer none){
 		prefix ="Sa";
 
 	gchar* backing_track_filename = g_strdup_printf("%s/backingtracks/%s_%s_$t_$p%s.ogg",AUDIO_DIR,prefix,name,postfix);
-	printf ("looking backing_track_filename: '%s'\n",backing_track_filename);
+	message=g_strdup_printf("Backintrack-selection: looking file '%s' ",backing_track_filename);
+	cem_add_to_log(message,J_LOG_USER_ACTION);
+	g_free(message);
 	if (adhoc_sequencer){
-		jammo_sequencer_stop(adhoc_sequencer);
+		g_object_set(adhoc_sequencer,"play",FALSE,NULL);
+		g_object_unref(adhoc_sequencer);
+		adhoc_sequencer=NULL;
 	}
 
 	adhoc_sequencer = jammo_sequencer_new();
@@ -126,28 +139,34 @@ void backingtrack_song_clicked (TangleButton* tanglebutton, gpointer none){
 
 
 void backingtrack_selection_vocal_clicked(TangleButton* tanglebutton, gpointer none){
-	printf("backingtrack_selection_vocal_clicked\n");
 	vocal_selected = tangle_button_get_selected(tanglebutton);
 
 	if (vocal_selected) {
+	 cem_add_to_log("Backintrack-selection: vocal selected",J_LOG_USER_ACTION);
 	 tangle_button_set_selected(TANGLE_BUTTON(jammo_get_actor_by_id("backingtrack-selection-melodical")),FALSE);
 	 melodic_selected=FALSE;
 	}
+	else {
+		 cem_add_to_log("Backintrack-selection: vocal deselected",J_LOG_USER_ACTION);
+	}
 }
 
 void backingtrack_selection_melodical_clicked(TangleButton* tanglebutton, gpointer none){
-	printf("backingtrack_selection_vocal_clicked\n");
 	melodic_selected = tangle_button_get_selected(tanglebutton);
 
 	if (melodic_selected) {
+	 cem_add_to_log("Backintrack-selection: melodic selected",J_LOG_USER_ACTION);
 	 tangle_button_set_selected(TANGLE_BUTTON(jammo_get_actor_by_id("backingtrack-selection-vocal")),FALSE);
 	 vocal_selected=FALSE;
 	}
+	else {
+		 cem_add_to_log("Backintrack-selection: melodic deselected",J_LOG_USER_ACTION);
+	}
 }
 
 static void end_backingtrack_selection() {
 	if (adhoc_sequencer) {
-		jammo_sequencer_stop(adhoc_sequencer);
+		g_object_set(adhoc_sequencer,"play",FALSE,NULL);
 		g_object_unref(adhoc_sequencer);
 		adhoc_sequencer=NULL;
 	}
@@ -161,18 +180,17 @@ static void end_backingtrack_selection() {
 		g_free(image_name_for_last_played);
 		image_name_for_last_played=NULL;
 	}
-
-	clutter_actor_hide(jammo_get_actor_by_id("backingtrack-selection-view"));
+	static_backingtrack = NULL;
+	tangle_actor_hide_animated(TANGLE_ACTOR(jammo_get_actor_by_id("backingtrack-selection-view")));
 	return_to_fullsequencer_gui();
 }
 
 
 void backingtrack_selection_ok_clicked(TangleButton* tanglebutton, gpointer none){
-	printf("backingtrack_selection_ok_clicked\n");
+	cem_add_to_log("Backintrack-selection: OK clicked",J_LOG_USER_ACTION);
 
 	if (last_played_filename) {
-		//Convention: There are always one backing-track-view, with this ID. FIXME: this is not good convention
-		ClutterActor* track_view = jammo_get_actor_by_id("BackingTrack");
+		ClutterActor* track_view = static_backingtrack;
 		if (track_view) {
 			//audio
 			JammoTrack* track = NULL;
@@ -180,7 +198,7 @@ void backingtrack_selection_ok_clicked(TangleButton* tanglebutton, gpointer none
 			if (track) {
 				g_object_set(track,"filename",last_played_filename,NULL);
 			} else {
-				printf("Can't change backingtrack audio! No track found. Will not change image\n");
+					cem_add_to_log("Backintrack-selection: No track found.",J_LOG_FATAL);
 				return;
 			}
 
@@ -189,7 +207,7 @@ void backingtrack_selection_ok_clicked(TangleButton* tanglebutton, gpointer none
 			//printf ("image_file '%s'\n",image_file);
 			ClutterActor* new_back = clutter_texture_new_from_file(image_file, NULL);
 			if (new_back==NULL) {
-				printf("Can't find image. Using gray texture.\n");
+				cem_add_to_log("Backintrack-selection: No image found, using gray texture",J_LOG_FATAL);
 				new_back = clutter_rectangle_new_with_color (clutter_color_new(100,100,100,100));
 				clutter_actor_set_size(new_back, clutter_actor_get_width(track_view), clutter_actor_get_height(track_view));
 			}
@@ -206,7 +224,7 @@ end_backingtrack_selection();
 
 
 void backingtrack_selection_cancel_clicked(TangleButton* tanglebutton, gpointer none){
-	printf("backingtrack_selection_cancel_clicked\n");
+	cem_add_to_log("Backintrack-selection: cancel clicked",J_LOG_USER_ACTION);
 	end_backingtrack_selection();
 }
 
@@ -223,13 +241,13 @@ static void roll_song_list(int direction) {
 }
 
 void backingtrack_up_arrow_clicked(TangleButton* tanglebutton, gpointer none){
-	printf("backingtrack_up_arrow_clicked\n");
+	cem_add_to_log("Backintrack-selection: up arrow clicked",J_LOG_USER_ACTION);
 	roll_song_list(-1); //up
 }
 
 
 void backingtrack_down_arrow_clicked(TangleButton* tanglebutton, gpointer none){
-printf("backingtrack_down_arrow_clicked\n");
+	cem_add_to_log("Backintrack-selection: down arrow clicked",J_LOG_USER_ACTION);
 	roll_song_list(1); //down
 }
 
