@@ -6,6 +6,8 @@
 #include "string.h"
 #include <time.h>
 #include <stdlib.h>
+#include <sys/stat.h>
+#include "mysongs.h"
 #include "community_utilities.h"
 #include "../jammo.h"
 #include "../../meam/jammo-sample.h"
@@ -14,19 +16,17 @@
 #include "../file_helper.h"
 #include "sequencer.h"
 
-/*
-*Function computes the length of the click.
-*If the length of the click is more than 1 seconds, function to rename the item is called.
-*Otherwise a function to play the appropriate music piece is called. 
-*/
 
-void song_name_press_action(ClutterActor* loopName){
+// milliseconds
+#define DURATION_OF_LONG_CLICK 1500
 
-	static gboolean clicked = FALSE;
-	static struct timeval timePressed;
-	struct timeval timeReleased;
+//Long click:  rename the item
+static gboolean tap_and_hold_function(gpointer user_data) {
+	ClutterActor* actor=CLUTTER_ACTOR(user_data);
+	g_object_set_data(G_OBJECT(actor),"handler_for_longclick",GUINT_TO_POINTER(0));
 
-	const char* filename = clutter_actor_get_name(loopName);
+
+	const char* filename = clutter_actor_get_name(actor);
 	char* projects = configure_get_projects_directory();
 	char* finalized = configure_get_finalized_directory();
 	int type = -1;
@@ -36,40 +36,91 @@ void song_name_press_action(ClutterActor* loopName){
 	}else if(strncmp(finalized, filename, strlen(finalized)) == 0){ // finished song
 		type = 1;
 	}
-	clicked = !clicked;
 
-	if(clicked){
-		gettimeofday(&timePressed, NULL);
-	}else{	
-		gettimeofday(&timeReleased, NULL);
-		
-		if(timeReleased.tv_sec-timePressed.tv_sec > 1){
-			if(type == 0 || type == 1)
-				rename_loop(loopName, type);	
-		}else if((timeReleased.tv_sec-timePressed.tv_sec == 1) && (timeReleased.tv_usec >= timePressed.tv_usec)){
-			if(type == 0 || type == 1)
-				rename_loop(loopName, type);	
-		}else{
-			if(type == 0){ 
-				sequencer_start_with_file((gchar*)filename);
-			}else if(type == 1){ 
-				play_selected_loop(loopName);
-			}
-		}
-	}	
-	
+	rename_loop(actor, type);
+	return FALSE;
 }
 
+//Short click: play
+static void name_clicked(ClutterActor* actor) {
+	const char* filename = clutter_actor_get_name(actor);
+	char* projects = configure_get_projects_directory();
+	char* finalized = configure_get_finalized_directory();
+	int type = -1;
+
+	if(strncmp(filename, projects, strlen(projects)) == 0){ // project
+		type = 0;
+	}else if(strncmp(finalized, filename, strlen(finalized)) == 0){ // finished song
+		type = 1;
+	}
+
+	if(type == 0){
+		start_sequencer_with_this_file(actor, NULL);
+	}else if(type == 1){
+		play_selected_loop(actor);
+	}else{
+		printf("Invalid loop name\n");
+	}
+}
+
+
+gboolean song_name_press_action (ClutterActor* actor, ClutterButtonEvent *event) {
+	guint holding_event_source_id = g_timeout_add(DURATION_OF_LONG_CLICK, tap_and_hold_function, actor);
+	g_object_set_data(G_OBJECT(actor),"handler_for_longclick",GUINT_TO_POINTER(holding_event_source_id));
+
+	return TRUE;
+}
+
+
+gboolean song_name_release_action (ClutterActor* actor, ClutterButtonEvent *event) {
+	guint holding_event_source_id= GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(actor),"handler_for_longclick"));
+	if (holding_event_source_id) {
+		g_source_remove(holding_event_source_id);
+		g_object_set_data(G_OBJECT(actor),"handler_for_longclick",GUINT_TO_POINTER(0));
+
+		//If tap_and_hold_function is triggered, we do not want call this:
+		name_clicked(actor);
+	}
+
+	return TRUE;
+}
+
+
+
 void rename_loop(ClutterActor *loopName, int type){
 
 	static gboolean firstCall = TRUE;
 
 	ClutterActor *text = tangle_button_get_normal_background_actor(TANGLE_BUTTON(loopName));
-
 	const char* givenname = clutter_text_get_text(CLUTTER_TEXT(text));
 	const char* filename = clutter_actor_get_name(loopName);
+	gchar * newpath;
+	int i = 0, j = 0, type_length = 0, path_length = 0;
+	int length = strlen(filename);
+	char temp[length];
+	char oldpath[length];
 
-	printf("FILENAME:%s\n", filename);
+	strcpy(temp, filename);
+
+	if(type == 0){ //projects
+		path_length = strlen(configure_get_projects_directory());
+		type_length = 5; //.json
+	}else if(type == 1 || type == 3){ //songs
+		path_length = strlen(configure_get_finalized_directory());
+		type_length = 4; //.ogg
+	}
+		
+	for(i = path_length + 1; i < length-type_length; i++){
+		oldpath[j] = temp[i];
+		j++;
+	}
+	oldpath[j] = 0;
+
+	gchar * path = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), 
+			gems_profile_manager_get_userid(NULL), oldpath);
+
+	printf("Path: %s\n", path);
+	printf("Filename is:%s\n", filename);
 
 	if(firstCall == TRUE){
 		firstCall = FALSE;
@@ -95,8 +146,14 @@ void rename_loop(ClutterActor *loopName, int type){
 			strcat(new_projects_name, "/");
 			strcat(new_projects_name, givenname);
 			strcat(new_projects_name, ".json");
-			printf("newname: %s.\n", new_projects_name);
+			printf("Newname: %s.\n", new_projects_name);
 
+			if(file_exist(path)){ //labelfile exists
+				newpath = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), 
+							gems_profile_manager_get_userid(NULL), givenname);
+				printf("Newpath: %s\n", newpath);
+				rename(path, newpath);
+			}
 			rename(filename, new_projects_name);
 			clutter_actor_set_name(loopName, new_projects_name);
 
@@ -110,8 +167,14 @@ void rename_loop(ClutterActor *loopName, int type){
 			strcat(newname, "/");
 			strcat(newname, givenname);
 			strcat(newname, ".ogg");
-			printf("newname: %s.\n", newname);
+			printf("Newname: %s.\n", newname);
 
+			if(file_exist(path)){ //labelfile exists
+				newpath = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), 
+							gems_profile_manager_get_userid(NULL), givenname);
+				printf("Newpath: %s\n", newpath);
+				rename(path, newpath);
+			}
 			rename(filename, newname);
 			clutter_actor_set_name(loopName, newname);
 		}
@@ -134,20 +197,16 @@ void play_selected_loop(ClutterActor *actor){
 			printf("Now playing: %s\n", filename);
 			sample = jammo_sample_new_from_file(filename);
 		}
-	
 		jammo_sample_play(sample);
-	}
-	
-	else{
+	}else{
 		puts("loop stop");
 		jammo_sample_stop(sample);
 		g_object_unref(sample);
 		sample = NULL;
-	
 	}
-
 }
 
+
 void show_song_label(show_label_params *params){
 
 	puts("Starting record label view.");
@@ -196,7 +255,6 @@ void show_song_label(show_label_params *params){
 			}
 			
 		}
-		
 		fclose(file);
 	}
 		
@@ -214,7 +272,9 @@ void hide_song_label(gchar* parentview){
 		
 }
 
-
+/*
+ * Function for getting current time.
+ */
 time_type get_current_time(){
 
 	time_t now;
@@ -233,6 +293,22 @@ time_type get_current_time(){
 	return current_time;
 }
 
+/*
+ * Function for checking whether file exists.
+ */
+gboolean file_exist(gchar *filename) 
+{
+  	struct stat buffer;
+
+  	if(stat(filename, &buffer) == 0){
+    		return TRUE;
+  	}else{
+		printf("Cannot find file: %s\n", filename);
+    		return FALSE;
+  	}
+}
+
+
 /*
 * Function clears container that may contain other containers.
 *
@@ -240,8 +316,6 @@ time_type get_current_time(){
 * -listToClear is the container to be cleared
 *
 */
-
-
 void clear_container(ClutterContainer *listToClear){
 	
 	int i = 0;
@@ -365,6 +439,8 @@ void limit_line_count(TextField *text){
 			text->handler_id = g_signal_connect_swapped(text->text, "text-changed", (GCallback)limit_line_count, text);
 			layout = clutter_text_get_layout(CLUTTER_TEXT(text->text));
 	}
+	
+	g_free(textField);
 		
 }
 
