@@ -18,7 +18,7 @@ typedef struct {
 
 void start_discuss();
 gboolean addDiscussion(char* name, int num);
-gboolean addThread(char* name, int num);
+gboolean addThread(char* name, int num, guint32 user_id);
 ClutterActor *create_line(int y, int length, int size, ClutterContainer *cont);
 gboolean discuss_change_to_discussion_view(TangleActor *actor, gpointer data);
 gboolean discuss_change_to_discussion_threads_view(TangleActor *actor, gpointer data);
@@ -31,5 +31,6 @@ void start_discussionthreads();
 void start_addthread_view();
 void discuss_change_to_add_thread_view();
 void add_new_thread();
+void end_discuss();
 
 #endif 
