@@ -105,9 +105,9 @@ GList* helpdesk_get_number_of_questions(void)
 void helpdesk_show_helpdesk_view(void)
 {
 	GList *questions = helpdesk_get_number_of_questions();
+	GList *l = 0; //Iterator
 
 	int number_of_questions = g_list_length(questions);
-	int i = 0;
 
 	ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
 	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
@@ -118,7 +118,7 @@ void helpdesk_show_helpdesk_view(void)
 		clutter_actor_show(CLUTTER_ACTOR(help_view));
 		clutter_actor_show(jammo_get_actor_by_id("helpdesk-no-questions-textfield"));
 
-		if(number_of_questions > 4)
+		if(number_of_questions >= 5)
 		{
 			questionslist.list = CLUTTER_CONTAINER(jammo_get_actor_by_id("helpdesk-list-scrollable"));	
 			ClutterAction *listAction = tangle_actor_get_action_by_type(CLUTTER_ACTOR(questionslist.list), TANGLE_TYPE_SCROLL_ACTION);
@@ -130,16 +130,14 @@ void helpdesk_show_helpdesk_view(void)
 		{	
 			clutter_actor_hide(jammo_get_actor_by_id("helpdesk-no-questions-textfield"));
 			
-			do{	
-				if(i > 0)
-				questions = questions->next;
-
-				message *msg = questions->data;
-
-				helpdesk_add_question_to_list(msg, i, 0);
-				i++;
-			}while(questions->next != NULL);
+			for(l = questions; l; l = l->next)
+			helpdesk_add_question_to_list(l->data, 0);
 		}
+		if(number_of_questions <= 5)
+			clutter_actor_set_height(CLUTTER_ACTOR(questionslist.list), questionslist.listItemHeight * number_of_questions);	
+		
+		else	clutter_actor_set_height(CLUTTER_ACTOR(questionslist.list), questionslist.listItemHeight * 5);	
+
 	}
 	else 	cem_add_to_log(_("Can't find 'helpdesk-view'"), J_LOG_DEBUG);
 
@@ -159,7 +157,6 @@ void helpdesk_show_question_view(ClutterActor *actor)
 	printf(_("Showing Question: %d"), selectedQuestion);
 
 	start_thread_view(helpdesk_messages, "helpdesk", NULL, selectedQuestion);
-
 }
 
 void helpdesk_show_addquestion_view(void)
@@ -182,13 +179,13 @@ void helpdesk_show_addquestion_view(void)
 
 		addquestion_titleTextField.text = jammo_get_actor_by_id("helpdesk-addquestion-title");
 		addquestion_titleTextField.lineCount = 3;
-		addquestion_titleTextField.max_characters = 3;
+		addquestion_titleTextField.max_characters = 100;
 		addquestion_titleTextField.handler_id = g_signal_connect_swapped(addquestion_titleTextField.text,
 							"text-changed", (GCallback)limit_line_count, &addquestion_titleTextField);		
 
 		addquestion_questionTextField.text = jammo_get_actor_by_id("helpdesk-addquestion-description");
-		addquestion_questionTextField.lineCount = 9;
-		addquestion_questionTextField.lineCount = 3;
+		addquestion_questionTextField.lineCount = 11;
+		addquestion_questionTextField.lineCount = 300;
 		addquestion_questionTextField.handler_id = g_signal_connect_swapped(addquestion_questionTextField.text,
 							"text-changed", (GCallback)limit_line_count, &addquestion_questionTextField);		
 	}
@@ -236,13 +233,13 @@ void helpdesk_add_question(void)
 	strncpy(msg->sender, "Sender",20);
 	msg->sender[19] = 0;
 	strcpy(msg->time, now.time); 
-
+	msg->type = TEXT_COMMENT;
 	helpdesk_messages = g_list_append(helpdesk_messages, (gpointer)msg);
 
 	helpdesk_show_helpdesk_view();
 }
 
-gboolean helpdesk_add_question_to_list(gpointer data, int index, guint user_id)
+gboolean helpdesk_add_question_to_list(gpointer data, guint user_id)
 {	
 	ClutterContainer *listContainer = CLUTTER_CONTAINER(clutter_group_new());
 	ClutterActor *colorbar = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar13.png",NULL);
@@ -254,12 +251,10 @@ gboolean helpdesk_add_question_to_list(gpointer data, int index, guint user_id)
 
 	message *msg = data;
 
-	char topictitle[33];
-	strncpy(topictitle, msg->title, 33);
-	topictitle[29] = topictitle[30] = topictitle[31] = '.'; 
-	topictitle[32] ='\0'; 
+	char topictitle[25];
+	strncpy(topictitle, msg->title, 25);
 
-	ClutterActor *text = clutter_text_new_with_text("Comic Sans 20", topictitle);	
+	ClutterActor *text = clutter_text_new_with_text(TEXT_CAPTION, topictitle);	
 	ClutterActor *questionButton = tangle_button_new_with_background_actor(text);
 
 	profile_view_params *params = malloc(sizeof(profile_view_params));
@@ -304,12 +299,7 @@ gboolean helpdesk_add_question_to_list(gpointer data, int index, guint user_id)
 						clutter_actor_get_parent(commentButton));
 	g_signal_connect_swapped(CLUTTER_ACTOR(composer), "clicked", G_CALLBACK(start_profile_view), (gpointer)params);
 
-	clutter_container_add_actor(questionslist.list, CLUTTER_ACTOR(listContainer));
-
-	if(index <= 5)
-		clutter_actor_set_height(CLUTTER_ACTOR(questionslist.list), questionslist.listItemHeight * (index+1));	
-	else
-		clutter_actor_set_height(CLUTTER_ACTOR(questionslist.list), questionslist.listItemHeight * 5);		
+	clutter_container_add_actor(questionslist.list, CLUTTER_ACTOR(listContainer));	
 
 	return TRUE;
 }
