@@ -21,7 +21,7 @@ void helpdesk_get_questions(void);
 GList* helpdesk_get_number_of_questions(void);
 
 //Functions for creating and moving loops
-gboolean helpdesk_add_question_to_list(gpointer data, int index, guint user_id);
+gboolean helpdesk_add_question_to_list(gpointer data, guint user_id);
 
 void helpdesk_find_selected_actor(ClutterActor *actor);
 
