@@ -541,6 +541,9 @@ void instrument_gui_start (JammoMiditrackView* miditrack_view, TangleWidget* sli
 		//Make ad-hoc-track using same type
 		int type;
 		g_object_get(static_slider_track,"slider-type",&type,NULL);
+		gchar* message = g_strdup_printf("Starting instrument-gui with slider-type: %d",type);
+		cem_add_to_log(message,J_LOG_DEBUG);
+		g_free(message);
 
 		ad_hoc_slider_track = jammo_slider_track_new (type);
 		jammo_sequencer_add_track (ad_hoc_sequencer, JAMMO_TRACK (ad_hoc_slider_track));
@@ -567,6 +570,9 @@ void instrument_gui_start (JammoMiditrackView* miditrack_view, TangleWidget* sli
 
 		int type;
 		g_object_get(track,"instrument-type",&type,NULL);
+		gchar* message = g_strdup_printf("Starting instrument-gui with instrument-type: %d",type);
+		cem_add_to_log(message,J_LOG_DEBUG);
+		g_free(message);
 
 		clutter_actor_hide(jammo_get_actor_by_id("instrument-slider"));
 		clutter_actor_hide(jammo_get_actor_by_id("instrument-two-rows-keyboard"));
