@@ -19,7 +19,7 @@ static gint listItemHeight = 0;
 void start_jammosounds(){
 
 
-	int numberOfLoops = 6; //this should contain the number of loops in the list
+	int numberOfLoops = 0; //this should contain the number of loops in the list
 
 	printf("Starting JamMoSounds\n");
 
@@ -92,10 +92,10 @@ gboolean add_loop_to_list(char* name, int numberOfLoops){
 	clutter_container_add_actor(listContainer, instrument);
 	
 	
-	//TODO: add correct font	
-	
-	text = clutter_text_new_with_text("Comic Sans MS", "Loop name here");	
+	text = clutter_text_new_with_text(TEXT_NORMAL, "Loop name here");	
 	loopName = tangle_button_new_with_background_actor(text);
+	clutter_actor_set_name(loopName, "Loop name here");
+
 	clutter_actor_set_position(loopName, 230, listItemHeight/5*2);
 	clutter_container_add_actor(listContainer, loopName);	
 
@@ -113,7 +113,7 @@ gboolean add_loop_to_list(char* name, int numberOfLoops){
 				clutter_actor_get_parent(importButton));
 	
 	g_signal_connect_swapped(loopName, "button-press-event", G_CALLBACK(song_name_press_action), loopName);
-	g_signal_connect_swapped(loopName, "button-release-event", G_CALLBACK(song_name_press_action), loopName);
+	g_signal_connect_swapped(loopName, "button-release-event", G_CALLBACK(song_name_release_action), loopName);
 	
 	clutter_container_add_actor(list, CLUTTER_ACTOR(listContainer));
 	
@@ -172,7 +172,7 @@ void import_selected_loop(ClutterActor *loop){
 	
 	}
 	
-	ClutterActor *text = clutter_text_new_with_text("Times", "TEST");
+	ClutterActor *text = clutter_text_new_with_text(TEXT_NORMAL, "TEST");
 	
 	clutter_container_add_actor(children->data, text);
 	
