@@ -1,4 +1,4 @@
-/**sequencer is part of JamMo.
+/*
 License: GPLv2, read more from COPYING
 
 This file is for clutter based gui.
@@ -13,15 +13,17 @@ void start_mysongs();
 
 void mysongs_goto_communitymenu(TangleButton *tanglebutton, gpointer none);
 void mysongs_goto_startmenu(TangleButton *tanglebutton, gpointer none);
-
+void mysongs_end_mysongs();
 //Functions for creating and moving loops
 gboolean mysongs_add_loop_to_list(char* loopName, int numberOfLoops);
-void mysongs_autoscroll_to_correct_pos(ClutterActor *listToScroll);
 void mysongs_delete_song(ClutterActor *actor);
 void mysongs_remove_song_view(ClutterActor *actor);
 void mysongs_cancel_song_delete(ClutterActor *actor);
 void mysongs_get_comments(ClutterActor* song);
 void mysongs_comment(ClutterActor *actor);
 void mysongs_refresh_list();
+void mysongs_update_label_button(const gchar* path);
+void mysongs_label_button_clicked(ClutterActor* label);
+void start_sequencer_with_this_file(ClutterActor *actor, gpointer none);
 
 #endif 
