@@ -92,6 +92,8 @@ g_assert (object != NULL);
 	gint tempo = 110; //'normal' tempo
 	gchar* pitch ="D";  //'normal' pitch
 
+	guint64 duration  = 0; //Duration is mandatory
+
 	//META data: Load these only once
 if (load_only_backingtrack){
 	//int
@@ -106,10 +108,18 @@ if (load_only_backingtrack){
 		pitch = (gchar*)  json_node_get_string (node);
 		printf("pitch: '%s'\n",pitch);
 	}
+	//guint64
+	node = json_object_get_member (object, "duration");
+	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE){
+		duration =  json_node_get_int (node);
+		printf("duration: '%" G_GUINT64_FORMAT "'\n",duration);
+	}
 
 	jammo_sequencer_set_tempo(static_sequencer,tempo);
 	jammo_sequencer_set_pitch(static_sequencer,pitch);
 	//These will be synced after loading
+
+	sequencer_track_view_set_duration(duration);
 }
 
 
@@ -171,7 +181,7 @@ if (load_only_backingtrack){
 				//printf(" name of track: '%s'\n",name_of_track);
 			}
 
-#ifdef not_implemented
+
 			//BACKING-TRACK
 			if (strncmp(track_type, "BackingTrack", 12) == 0) {
 				//printf("Found BackingTrack\n");
@@ -182,13 +192,18 @@ if (load_only_backingtrack){
 					backing_track_filename =(gchar*)  json_node_get_string (sub_node);
 					//printf("backing_track_filename: '%s'\n",backing_track_filename);
 
-					track = JAMMO_TRACK(jammo_backing_track_new(backing_track_filename));
-					// Create other tracks after the duration of the backing track is known.
+				gchar* image_filename="";
+				//string
+				sub_node = json_object_get_member (sub_object, "image-file");
+				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
+					image_filename =(gchar*)  json_node_get_string (sub_node);
+					//printf("image_filename: '%s'\n",image_filename);
+				}
 
-					//track_view=sequencer_track_view_add_backing_track(track, muted,volume); //TODO
+				track_view=sequencer_track_view_create_backing_track(muted,volume,backing_track_filename,image_filename,name_of_track);
 				}
 			} //Backing-track over
-#endif
+
 
 			//EDITING-TRACK
 			if(strncmp(track_type, "EditingTrack", 12) == 0) {
@@ -338,6 +353,11 @@ static void levelview_loaded(ClutterActor *levelview, gpointer none) {
 	g_signal_handlers_disconnect_by_func(levelview, levelview_loaded, NULL);
 	const gchar* levelname = clutter_actor_get_name(levelview);
 
+	//Volumebar must be showed, unless first time using it, it shows volume=0.
+	//Now we can hide it.
+	ClutterActor* volume_container = jammo_get_actor_by_id("fullsequencer-volumebar-container");
+	clutter_actor_hide(volume_container);
+
 	//Make sample-buttons on wheel-game
 	//This can take time (thus we have hourglass on screen)
 	if (strcmp(levelname,"level1")==0)  //optimization: Level1 doesn't need them all.
@@ -422,13 +442,19 @@ void start_fullsequencer_gui(ClutterActor* levelview)
 	g_signal_connect(current_levelview, "show-completed", G_CALLBACK(levelview_loaded), NULL); //Continue after animated show
 	clutter_actor_show(current_levelview);
 
+	//Volumebar must be showed, unless first time using it, it shows volume=0.
+	ClutterActor* volume_container = jammo_get_actor_by_id("fullsequencer-volumebar-container");
+	clutter_actor_show(volume_container);
+
 	ClutterAction* action = tangle_actor_get_action_by_type(jammo_get_actor_by_id("fullsequencer-view-container"), TANGLE_TYPE_SCROLL_ACTION);
 	g_signal_connect_swapped(action, "clamp-offset-y", G_CALLBACK(tangle_widget_clamp_child_boundaries), jammo_get_actor_by_id("fullsequencer-view-container"));
 
 	static_sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 	static_metronome_track = NULL;
 
-	sequencer_track_view_tune_width();
+	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
+	guint64 duration = jammo_sequencer_get_duration(sequencer);
+	sequencer_track_view_set_duration(duration);
 
 	sequencer_change_to_sequencer_view(NULL,NULL); //Start to middle view. //TODO:do inside JSON
 
@@ -449,7 +475,7 @@ void return_to_fullsequencer_gui(){
 /*
  * CallBack for JSON
  */
-void fullsequencer_home_clicked (TangleButton* tanglebutton, gpointer none){
+static void leave_fullsequencer() {
 	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 
 	jammo_sequencer_stop(sequencer);
@@ -458,6 +484,10 @@ void fullsequencer_home_clicked (TangleButton* tanglebutton, gpointer none){
 
 	tangle_view_unload(TANGLE_VIEW(current_levelview));
 	current_levelview=NULL;
+}
+
+void fullsequencer_home_clicked (TangleButton* tanglebutton, gpointer none){
+	leave_fullsequencer();
 	startmenu_goto_startmenu(NULL,NULL);
 }
 
@@ -519,6 +549,16 @@ static void on_rendering_stopped(JammoSequencer* sequencer, gpointer none) {
 void sequencer_render_button_pressed (TangleButton* tanglebutton, gpointer none){
 	cem_add_to_log("Render-button pressed",J_LOG_USER_ACTION);
 
+	//If sequencer is playing, use render button as stop-button.
+	gboolean play;
+	g_object_get(static_sequencer,"play",&play,NULL);
+
+	if (play) {
+		jammo_sequencer_stop(static_sequencer);
+		cem_add_to_log(" Sequencer was playing/rendering -> stop",J_LOG_DEBUG);
+		return;
+	}
+
 	char timestamp [80];
 	cem_get_time(timestamp);
 
@@ -546,9 +586,10 @@ void sequencer_render_button_pressed (TangleButton* tanglebutton, gpointer none)
 void sequencer_save_project_button_pressed (TangleButton* tanglebutton, gpointer none){
 	cem_add_to_log("Saving project file",J_LOG_INFO);
 	gchar* meta_data = g_strdup_printf
-      ("\"pitch\" : \"%s\",\n\"tempo\" : %d,\n",
+      ("\"pitch\" : \"%s\",\n\"tempo\" : %d,\n\"duration\" : %" G_GUINT64_FORMAT ",\n",
       jammo_sequencer_get_pitch(static_sequencer),
-      jammo_sequencer_get_tempo(static_sequencer));
+      jammo_sequencer_get_tempo(static_sequencer),
+      jammo_sequencer_get_duration(static_sequencer));
 
 	save_composition(configure_get_projects_directory(), "", jammo_get_actor_by_id("fullsequencer-container-for-tracks"),meta_data);
 	g_free(meta_data);
@@ -558,6 +599,7 @@ void sequencer_save_project_button_pressed (TangleButton* tanglebutton, gpointer
 
 
 void sequencer_mysongs_button_pressed (TangleButton* tanglebutton, gpointer none){
+	leave_fullsequencer();
 	start_mysongs();
 }
 
