@@ -772,6 +772,15 @@ static samplebutton_tuple level1_melodics[] = {
 };
 
 
+static gboolean sample_button_listened(JammoSampleButton* sample_button, gpointer data){
+	gchar* name;
+	g_object_get(sample_button,"sample-filename", &name,NULL);
+	gchar *message = g_strdup_printf("Sample '%s' listened on stage",name);
+	cem_add_to_log(message,J_LOG_USER_ACTION);
+	g_free(message);
+	return TRUE;
+}
+
 /*
 loop_type:
 1000=rhythms
@@ -804,7 +813,8 @@ static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[],
 		jammo_sample_button_set_image_filename(JAMMO_SAMPLE_BUTTON(sample_button),full_image);
 		jammo_sample_button_set_sample_filename(JAMMO_SAMPLE_BUTTON(sample_button), full_sound);
 
-
+		//Logging
+		g_signal_connect (sample_button, "listened", G_CALLBACK (sample_button_listened),NULL);
 
 		g_object_set(sample_button,"drag-threshold-y",10000,NULL); //No dragging by vertical-axis (it is for scrolling wheel)
 		g_signal_connect(sample_button,"drag-begin", G_CALLBACK(sample_button_drag_begin),NULL);
