@@ -35,13 +35,13 @@ enum {
 };
 
 
-void sequencer_track_view_tune_width();
-ClutterActor* sequencer_track_view_add_backing_track(JammoTrack* track, gboolean muted, gfloat volume);
-ClutterActor* sequencer_track_view_add_with_type(gint track_view_type, gboolean muted, gfloat volume, gint optional_parameter);
+void sequencer_track_view_set_duration(guint64 duration);
 
 ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat volume, gint e_type, gchar* name_of_track_view);
-ClutterActor* sequencer_track_view_create_instrument_track(gboolean muted, gfloat volume, gint instrument_type, gchar* name_of_track_view);
-//void sequencer_sequencer_track_view_remove_last();
+ClutterActor* sequencer_track_view_create_instrument_track(gboolean muted, gfloat volume, gint instrument_type, gchar*
+name_of_track_view);
+ClutterActor* sequencer_track_view_create_backing_track(gboolean muted, gfloat volume, gchar* audio, gchar* image, gchar* name_of_track_view);
+
 bool save_sequencer_state();
 
 #endif /* SEQUENCER_SEQUENCER_H_ */
