@@ -180,6 +180,8 @@ void save_composition(gchar* folder, gchar* to_filename, ClutterActor* sequencer
 
 			fprintf(ofp,"\n\t{\n");
 			fprintf(ofp,"\t\"track-type\" : \"VirtualInstrumentTrack\",\n");
+			const gchar* name_of_track = clutter_actor_get_name(track_view);
+			fprintf(ofp,"\t\"name\" : \"%s\",\n",name_of_track);
 			fprintf(ofp,"\t\"instrument\" : %d",type);
 
 			GList* list= jammo_instrument_track_get_event_list(JAMMO_INSTRUMENT_TRACK(track));
@@ -206,8 +208,11 @@ void save_composition(gchar* folder, gchar* to_filename, ClutterActor* sequencer
 			int type;
 			g_object_get(track,"slider-type",&type,NULL);
 
+
 			fprintf(ofp,"\n\t{\n");
 			fprintf(ofp,"\t\"track-type\" : \"SliderTrack\",\n");
+			const gchar* name_of_track = clutter_actor_get_name(track_view);
+			fprintf(ofp,"\t\"name\" : \"%s\",\n",name_of_track);
 			fprintf(ofp,"\t\"instrument\" : \"%d\"",type);
 
 			GList* list= jammo_slider_track_get_event_list(JAMMO_SLIDER_TRACK(track));
@@ -231,8 +236,17 @@ void save_composition(gchar* folder, gchar* to_filename, ClutterActor* sequencer
 			gchar *filename;
 			g_object_get(track,"filename",&filename,NULL);
 
+			ClutterActor* back;
+			g_object_get(track_view,"background-actor",&back,NULL);
+
+			gchar* image_filename;
+			g_object_get(back,"filename",&image_filename,NULL);
+
 			fprintf(ofp,"\n\t{\n");
 			fprintf(ofp,"\t\"track-type\" : \"BackingTrack\",\n");
+			const gchar* name_of_track = clutter_actor_get_name(track_view);
+			fprintf(ofp,"\t\"name\" : \"%s\",\n",name_of_track);
+			fprintf(ofp,"\t\"image-file\" : \"%s\",\n",image_filename);
 			fprintf(ofp,"\t\"audio-file\" : \"%s\"",filename);
 			WRITE_VOLUME_AND_MUTED
 			fprintf(ofp,"\t}");
