@@ -427,6 +427,17 @@ static void jammo_editing_track_view_finalize(GObject* object) {
 }
 
 static void jammo_editing_track_view_dispose(GObject* object) {
+	JammoEditingTrackView* editing_track_view;
+	
+	editing_track_view = JAMMO_EDITING_TRACK_VIEW(object);
+	
+	if (editing_track_view->priv->track) {
+		g_object_unref(editing_track_view->priv->track);
+		editing_track_view->priv->track = NULL;
+	}
+	//When editing-track-view-widget is removed, all it's children is also removed
+	//And they are sending 'on_actor_removed'-signal. (but priv->track is already deleted)
+	g_signal_handlers_disconnect_by_func(editing_track_view,on_actor_removed,NULL);
 	G_OBJECT_CLASS(jammo_editing_track_view_parent_class)->dispose(object);
 }
 
