@@ -11,16 +11,30 @@
 #include "jammo-mentor.h"
 #include "../meam/jammo-sample.h"
 #include <time.h>
+#include <dbus/dbus-glib.h>
+#include <string.h>
 
 #include "../cem/cem.h"
 G_DEFINE_TYPE(JammoMentor, jammo_mentor, TANGLE_TYPE_BUTTON)
 
+#ifdef N900
+#include <mce/dbus-names.h>
+#include <mce/mode-names.h>
+#else
+#define MCE_TKLOCK_MODE_SIG "tklock_mode_ind"
+#define MCE_SERVICE "com.nokia.mce"
+#define MCE_SIGNAL_PATH "/com/nokia/mce/signal"
+#define MCE_SIGNAL_IF "com.nokia.mce.signal"
+#define MCE_DEVICE_LOCKED "locked"
+#endif
+
 enum {
 	PROP_0,
 	PROP_STANDBY_SCALE,
 	PROP_ACTIVE_SCALE,
 	PROP_IDLE_SPEECH,
-	PROP_IDLE_TIMEOUT
+	PROP_IDLE_TIMEOUT,
+	PROP_DEVICE_LOCKED
 };
 
 struct _JammoMentorPrivate {
@@ -30,6 +44,7 @@ struct _JammoMentorPrivate {
 	JammoMentorSpokenCallback idle_speech_spoken_callback;
 	gpointer idle_speech_spoken_user_data;
 	gulong idle_timeout;
+	gulong default_idle_timeout;
 	gchar* language;
 	
 	GList* spoken_speeches;
@@ -39,13 +54,18 @@ struct _JammoMentorPrivate {
 	gulong stage_captured_event_handler_id;
 	guint timeout_event_source_id;
 	time_t last_activity_time;
+	DBusGProxy* mce_proxy;
 	
 	guint idle_speech_spoken : 1;
 	guint interrupted : 1;
+	guint device_locked : 1;
+	guint passive_mode : 1;
+	guint holding_event_source_id;
 };
 
 static void speak(JammoMentor* mentor, const gchar* speech, gboolean highlight, gfloat offset_x, gfloat offset_y, JammoMentorSpokenCallback callback, gpointer user_data);
 static void set_idle_timeout(JammoMentor* mentor, gboolean activate);
+static void on_mce_tklock_mode_sig(DBusGProxy* proxy, const gchar* mode, gpointer user_data);
 
 static GList* mentors;
 
@@ -180,6 +200,31 @@ void jammo_mentor_set_language(JammoMentor* mentor, const gchar* language) {
 	mentor->priv->language = g_strdup(language);
 }
 
+void jammo_mentor_set_passive(JammoMentor* mentor, gboolean passive){
+	mentor->priv->passive_mode=passive;
+	if (passive) {
+		cem_add_to_log("Mentor goes to passive mode",J_LOG_DEBUG);
+		mentor->priv->passive_mode=1;
+		clutter_actor_set_opacity (CLUTTER_ACTOR(mentor), 60);
+		//store current idle_timeout
+		mentor->priv->default_idle_timeout=jammo_mentor_get_idle_timeout(mentor);
+		g_object_set (mentor,"idle-timeout", G_MAXULONG,NULL);
+	}
+	else {
+		cem_add_to_log("Mentor goes to active mode",J_LOG_DEBUG);
+		mentor->priv->passive_mode=0;
+		clutter_actor_set_opacity (CLUTTER_ACTOR(mentor), 255);
+		//return stored idle_timeout
+		jammo_mentor_set_idle_timeout(mentor,mentor->priv->default_idle_timeout);
+	}
+}
+
+
+gboolean jammo_mentor_get_device_locked(JammoMentor* mentor) {
+
+	return mentor->priv->device_locked;
+}
+
 JammoMentor* jammo_mentor_get_default(void) {
 
 	return (mentors ? JAMMO_MENTOR(mentors->data) : NULL);
@@ -242,6 +287,9 @@ static void jammo_mentor_get_property(GObject* object, guint prop_id, GValue* va
 		case PROP_IDLE_TIMEOUT:
 			g_value_set_ulong(value, mentor->priv->idle_timeout);
 			break;
+		case PROP_DEVICE_LOCKED:
+			g_value_set_boolean(value, mentor->priv->device_locked);
+			break;
 	        default:
 		        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		        break;
@@ -265,15 +313,59 @@ static void jammo_mentor_finalize(GObject* object) {
 }
 
 static void jammo_mentor_dispose(GObject* object) {
-	set_idle_timeout(JAMMO_MENTOR(object), FALSE);
+	JammoMentor* mentor;
+	
+	mentor = JAMMO_MENTOR(object);
+	
+	set_idle_timeout(mentor, FALSE);
+	
+	if (mentor->priv->mce_proxy) {
+		g_object_unref(mentor->priv->mce_proxy);
+		mentor->priv->mce_proxy = NULL;
+	}
 
 	G_OBJECT_CLASS(jammo_mentor_parent_class)->dispose(object);
 }
 
+
+static gboolean tap_and_hold_function(gpointer user_data) {
+	JammoMentor* mentor;
+	mentor = JAMMO_MENTOR(user_data);
+
+	mentor->priv->holding_event_source_id = 0;
+
+	cem_add_to_log("Mentor tap-and-hold",J_LOG_DEBUG);
+	jammo_mentor_shut_up(mentor);
+
+	jammo_mentor_set_passive(mentor,!mentor->priv->passive_mode);
+
+	return FALSE;
+
+}
+
+static gboolean jammo_mentor_pressed (ClutterActor *actor, ClutterButtonEvent *event) {
+	JAMMO_MENTOR(actor)->priv->holding_event_source_id = g_timeout_add(1500, tap_and_hold_function, actor);
+	return TRUE;
+}
+
+
+static gboolean jammo_mentor_released (ClutterActor *actor, ClutterButtonEvent *event) {
+	if (JAMMO_MENTOR(actor)->priv->holding_event_source_id) {
+		g_source_remove(JAMMO_MENTOR(actor)->priv->holding_event_source_id);
+		JAMMO_MENTOR(actor)->priv->holding_event_source_id = 0;
+
+		//If tap_and_hold_function is triggered, we do not want call this:
+		jammo_mentor_clicked(TANGLE_BUTTON(actor));
+	}
+
+	return TRUE;
+}
+
 static void jammo_mentor_class_init(JammoMentorClass* mentor_class) {
 	GObjectClass* gobject_class = G_OBJECT_CLASS(mentor_class);
 	ClutterActorClass* clutter_actor_class = CLUTTER_ACTOR_CLASS(mentor_class);
-	TangleButtonClass* button_class = TANGLE_BUTTON_CLASS(mentor_class);
+	//TangleButtonClass* button_class = TANGLE_BUTTON_CLASS(mentor_class);
+	//button_class->clicked = jammo_mentor_clicked;
 
 	gobject_class->finalize = jammo_mentor_finalize;
 	gobject_class->dispose = jammo_mentor_dispose;
@@ -282,8 +374,8 @@ static void jammo_mentor_class_init(JammoMentorClass* mentor_class) {
 
 	clutter_actor_class->show = jammo_mentor_show;
 	clutter_actor_class->hide = jammo_mentor_hide;
-
-	button_class->clicked = jammo_mentor_clicked;
+	clutter_actor_class->button_release_event = jammo_mentor_released;
+	clutter_actor_class->button_press_event = jammo_mentor_pressed;
 
 	/**
 	 * JammoMentor:standby-scale:
@@ -330,14 +422,37 @@ static void jammo_mentor_class_init(JammoMentorClass* mentor_class) {
 	                                                   "The time in seconds after the mentor will speak if an user has been idle.",
 	                                                   0, G_MAXULONG, 0,
 	                                                   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT));
+	/**
+	 * JammoMentor:device-locked:
+	 *
+	 * Whether the device is locked.
+	 *
+	 * Despite being conceptually unrelated to a mentor, this property keeps track of the device locking state.
+	 * The mentor itself will only speak if an user has been idle and the device is unlocked. Thus, it monitors
+	 * the device locking state and exposes the result for other uses also using this property.
+	 */
+	g_object_class_install_property(gobject_class, PROP_DEVICE_LOCKED,
+	                                g_param_spec_boolean("device-locked",
+	                                                     "Device locked",
+	                                                     "Whether the device is locked.",
+	                                                     FALSE,
+	                                                     G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_type_class_add_private (gobject_class, sizeof (JammoMentorPrivate));
 }
 
 static void jammo_mentor_init(JammoMentor* mentor) {
-	mentor->priv = G_TYPE_INSTANCE_GET_PRIVATE(mentor, JAMMO_TYPE_MENTOR, JammoMentorPrivate);
+	DBusGConnection* connection;
 
+	mentor->priv = G_TYPE_INSTANCE_GET_PRIVATE(mentor, JAMMO_TYPE_MENTOR, JammoMentorPrivate);
+	mentor->priv->passive_mode=0;
 	mentors = g_list_append(mentors, mentor);
+	
+	if ((connection = dbus_g_bus_get(DBUS_BUS_SYSTEM, NULL))) {
+		mentor->priv->mce_proxy = dbus_g_proxy_new_for_name(connection, MCE_SERVICE, MCE_SIGNAL_PATH, MCE_SIGNAL_IF);
+		dbus_g_proxy_add_signal(mentor->priv->mce_proxy, MCE_TKLOCK_MODE_SIG, G_TYPE_STRING, G_TYPE_INVALID);
+		dbus_g_proxy_connect_signal(mentor->priv->mce_proxy, MCE_TKLOCK_MODE_SIG, G_CALLBACK(on_mce_tklock_mode_sig), mentor, NULL);
+	}
 }
 
 static const gchar* find_characters(const gchar* string, const gchar* characters) {
@@ -453,9 +568,19 @@ static void real_speak(JammoMentor* mentor, const gchar* next_speech, JammoMento
 }
 
 static void speak(JammoMentor* mentor, const gchar* speech, gboolean highlight, gfloat offset_x, gfloat offset_y, JammoMentorSpokenCallback callback, gpointer user_data) {	
+
 	set_idle_timeout(mentor, FALSE);
 	tangle_actor_show(TANGLE_ACTOR(mentor));
-	
+
+	if (mentor->priv->passive_mode) {
+		cem_add_to_log(" Mentor in passive mode, skip",J_LOG_DEBUG);
+		if (callback) {
+			callback(mentor, speech, TRUE, user_data);
+			}
+	return;
+	}
+
+
 	if (mentor->priv->active_sample) {
 		jammo_sample_stop(mentor->priv->active_sample);
 	}
@@ -499,7 +624,7 @@ static void set_idle_timeout(JammoMentor* mentor, gboolean activate) {
 		mentor->priv->timeout_event_source_id = 0;
 	}
 	
-	if (activate && mentor->priv->idle_timeout && mentor->priv->idle_speech && !mentor->priv->idle_speech_spoken && !mentor->priv->active_sample && CLUTTER_ACTOR_IS_VISIBLE(mentor)) {
+	if (activate && mentor->priv->idle_timeout && !mentor->priv->device_locked && mentor->priv->idle_speech && !mentor->priv->idle_speech_spoken && !mentor->priv->active_sample && CLUTTER_ACTOR_IS_VISIBLE(mentor)) {
 		if (!mentor->priv->stage && (mentor->priv->stage = clutter_actor_get_stage(CLUTTER_ACTOR(mentor)))) {
 			mentor->priv->stage_captured_event_handler_id = g_signal_connect(mentor->priv->stage, "captured-event", G_CALLBACK(on_stage_captured_event), mentor);
 		}
@@ -512,3 +637,23 @@ static void set_idle_timeout(JammoMentor* mentor, gboolean activate) {
 		mentor->priv->stage = NULL;
 	}
 }
+
+static void on_mce_tklock_mode_sig(DBusGProxy* proxy, const gchar* mode, gpointer user_data) {
+	JammoMentor* mentor;
+	gboolean old_device_locked;
+	
+	mentor = JAMMO_MENTOR(user_data);
+
+	old_device_locked = mentor->priv->device_locked;
+	if (!strcmp(mode, MCE_DEVICE_LOCKED)) {
+		mentor->priv->device_locked = TRUE;
+		jammo_mentor_shut_up(mentor);
+	} else {
+		mentor->priv->device_locked = FALSE;
+		mentor->priv->idle_speech_spoken = FALSE;
+	}
+	if (old_device_locked != mentor->priv->device_locked) {
+		set_idle_timeout(mentor, !mentor->priv->device_locked);
+		g_object_notify(G_OBJECT(mentor), "device-locked");
+	}
+}
