@@ -197,7 +197,7 @@ If file is not found (or some other error case) values are not modifed.
  -> Caller should set own defaults before calling,
  (or check against NULL)
 */
-static void read_config_file(char* filename, gboolean* log_stdout, int* log_level,gchar** mentor_lang) {
+static void read_config_file(char* filename, gboolean* log_stdout, int* log_level,gchar** mentor_lang, gboolean* start_passive_mentor) {
 	JsonParser *parser;
 	parser = json_parser_new ();
 	g_assert (JSON_IS_PARSER (parser));
@@ -283,6 +283,10 @@ static void read_config_file(char* filename, gboolean* log_stdout, int* log_leve
 			*mentor_lang = g_strdup_printf("%s",mlang);
 		}
 
+	node = json_object_get_member (object, "START_WITH_PASSIVE_MENTOR");
+	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
+		*start_passive_mentor= json_node_get_boolean (node);
+
 	g_object_unref (parser);
 }
 
@@ -320,9 +324,10 @@ int main(int argc, char** argv) {
 	gboolean log_to_stdout = FALSE;
 	int log_level=J_LOG_NONE;
 	gchar* lang_of_mentor = g_strdup_printf("system");
+	gboolean start_passive_mentor = FALSE;
 
 	gchar* setting_file = g_strdup_printf("%s/jammo.config",configure_get_jammo_directory());
-	read_config_file(setting_file,&log_to_stdout,&log_level,&lang_of_mentor);
+	read_config_file(setting_file,&log_to_stdout,&log_level,&lang_of_mentor,&start_passive_mentor);
 	g_free(setting_file);
 
 	//LOGGING
@@ -491,6 +496,8 @@ int main(int argc, char** argv) {
 	jammo_mentor_set_language(jammo_mentor_get_default(),path);
 	g_free(path);
 
+	if (start_passive_mentor)
+		jammo_mentor_set_passive(jammo_mentor_get_default(),TRUE);
 
 	if (!strcmp(application_name,"jammo3_6")) { //start jammo 3-6 years
 		cem_add_to_log("Will start 3-6 years game", J_LOG_DEBUG);
