@@ -182,8 +182,12 @@ gboolean ProfileManager::loadEncryptedProfile(gchar* _username)
 	{
 		case 0:
 			return TRUE;
+		// Profile read failure
 		case 1:
+		// No profile
 		case 2:
+		// Profile version mismatch
+		case 3:
 		default:
 			return FALSE;
 	}
@@ -239,6 +243,8 @@ gboolean ProfileManager::saveEncryptedProfile()
 			case 5:
 			// encrypted profile size missing
 			case 6:
+			// profile version is invalid
+			case 7:
 			default:
 				iSavingRequired = TRUE;
 				return FALSE;
@@ -302,6 +308,11 @@ guint ProfileManager::getEncryptedProfileSize()
 	return iStorageAgent->getEncryptedProfileSize();
 }
 
+guint8 ProfileManager::getProfileVersion()
+{
+	return iStorageAgent->getProfileVersion();
+}
+
 gboolean ProfileManager::setSalt(guchar* _salt)
 {
 	if(iStorageAgent->isAuthenticated()) return iStorageAgent->setSalt(_salt);
@@ -463,6 +474,25 @@ guint32 profilemanager_get_avatarid(ProfileManager* _aManager)
 	return (guint32)strtoul((_aManager->ViewDetail(param)).c_str(),NULL,10);
 }
 
+guint8 profilemanager_get_profile_type(ProfileManager* _aManager)
+{
+	if(_aManager == NULL) return 0;
+	
+	string param = string(PROF_PARAM_TYPE);
+	guint8 type = (guint8)atoi(_aManager->ViewDetail(param).c_str());
+	
+	// Currently only 2 types of profiles
+	if(type < PROF_TYPE_LOCAL || type > PROF_TYPE_REMOTE) return 0;
+	else return type;
+}
+
+guint8 profilemanager_get_profile_version(ProfileManager* _aManager)
+{
+	if(_aManager == NULL) return 0;
+	
+	return _aManager->getProfileVersion();
+}
+
 gboolean profilemanager_set_username(ProfileManager* _aManager, gchar* _value)
 {
 	if(_aManager == NULL) return FALSE;
