@@ -58,6 +58,7 @@ public:
 	guchar* getProfileHash();
 	guchar* getEncryptedProfile();
 	guint getEncryptedProfileSize();
+	guint8 getProfileVersion();
 	
 	gboolean setSalt(guchar* _salt);
 	gboolean setPasswordHash(guchar* _password_hash);
@@ -193,6 +194,12 @@ guint32 profilemanager_get_points(ProfileManager* _aManager);
 /* Get avatar id */
 guint32 profilemanager_get_avatarid(ProfileManager* _aManager);
 
+/* Get profile type */
+guint8 profilemanager_get_profile_type(ProfileManager* _aManager);
+
+/* Get profile version */
+guint8 profilemanager_get_profile_version(ProfileManager* _aManager);
+
 /* Set own username */
 gboolean profilemanager_set_username(ProfileManager* _aManager, gchar* _value);
 
