@@ -39,6 +39,7 @@ StorageAgent::StorageAgent()
 	profile_hash = NULL;
 	encrypted_profile = NULL;
 	encrypted_profile_size = 0;
+	version = 0;
 	authenticated = FALSE;
 	profileloaded = FALSE;
 	
@@ -344,17 +345,18 @@ gboolean StorageAgent::deserializeProfile(gchar* profile)
 	
 	if(profile == NULL) return FALSE;
 	
-	if(Tokenize(string(profile), tokens, ",") != 8)	return FALSE;
+	if(Tokenize(string(profile), tokens, ",") != PROF_TOKENS)	return FALSE;
 	
 	// Save all the details to profileDetails container
-	profileDetails[PROF_PARAM_USERID] = tokens[0];
-	profileDetails[PROF_PARAM_USERNAME] = tokens[1];
-	profileDetails[PROF_PARAM_AUTHLEVEL] = tokens[2];
-	profileDetails[PROF_PARAM_FIRSTNAME] = tokens[3];
-	profileDetails[PROF_PARAM_LASTNAME] = tokens[4];
-	profileDetails[PROF_PARAM_POINTS] = tokens[5];
-	profileDetails[PROF_PARAM_AGE] = tokens[6];
-	profileDetails[PROF_PARAM_AVATARID] = tokens[7];
+	profileDetails[PROF_PARAM_TYPE] = tokens[0]; // Profile type (PROF_TYPE_LOCAL or PROF_TYPE_REMOTE)
+	profileDetails[PROF_PARAM_USERID] = tokens[1];
+	profileDetails[PROF_PARAM_USERNAME] = tokens[2];
+	profileDetails[PROF_PARAM_AUTHLEVEL] = tokens[3];
+	profileDetails[PROF_PARAM_FIRSTNAME] = tokens[4];
+	profileDetails[PROF_PARAM_LASTNAME] = tokens[5];
+	profileDetails[PROF_PARAM_POINTS] = tokens[6];
+	profileDetails[PROF_PARAM_AGE] = tokens[7];
+	profileDetails[PROF_PARAM_AVATARID] = tokens[8];
 	
 	return TRUE;
 }
@@ -362,7 +364,8 @@ gboolean StorageAgent::deserializeProfile(gchar* profile)
 gchar* StorageAgent::serializeProfile()
 {
 	// Save all the details to a string
-	string serialized = profileDetails[PROF_PARAM_USERID] + "," +
+	string serialized = profileDetails[PROF_PARAM_TYPE] + "," +
+		profileDetails[PROF_PARAM_USERID] + "," +
 		profileDetails[PROF_PARAM_USERNAME] + "," +
 	  profileDetails[PROF_PARAM_AUTHLEVEL] + "," +
 	  profileDetails[PROF_PARAM_FIRSTNAME] + "," +
@@ -405,6 +408,11 @@ guint StorageAgent::getEncryptedProfileSize()
 	return encrypted_profile_size;
 }
 
+guint8 StorageAgent::getProfileVersion()
+{
+	return version;
+}
+
 gboolean StorageAgent::setSalt(guchar* _salt)
 {
 	// Setting empty salt not allowed
@@ -520,8 +528,8 @@ gint StorageAgent::readProfile(gchar* username)
 				cem_add_to_log(logmsg,J_LOG_ERROR);
 				g_free(logmsg);
 				g_error_free(error);
-				g_free(profilefile);
-				g_free(filename);
+				if(profilefile) g_free(profilefile);
+				if(filename) g_free(filename);
 				return 1;
 			}
 		}
@@ -534,42 +542,63 @@ gint StorageAgent::readProfile(gchar* username)
 			// Free existing
 			if(salt) g_free(salt);
 			
-			// Extract salt
-			salt = (guchar*)g_malloc(sizeof(guchar*) * AES_SALT_LENGTH);
-			memset(salt,0,AES_SALT_LENGTH);
-			*(guint32*)&salt[0] = *(guint32*)&contents[0];
-			*(guint32*)&salt[sizeof(guint32)] = *(guint32*)&contents[sizeof(guint32)];
+			// Extract version
+			version = *(guint8*)&contents[0];
+			if(version != JAMMO_PROFILE_VERSION)
+			{
+				logmsg = g_strdup_printf("StorageAgent::readProfile : Profile version is not compatible, read version = %d, JAMMO_PROFILE_VERSION = %d. Profile is not loaded!",
+					version, JAMMO_PROFILE_VERSION);
+				cem_add_to_log(logmsg,J_LOG_ERROR);
+				g_free(logmsg);
+				profileloaded = FALSE;
+				if(profilefile) g_free(profilefile);
+				if(filename) g_free(filename);
+				if(contents) g_free(contents);
+				return 3;
+			}
+			else
+			{
+				logmsg = g_strdup_printf("StorageAgent::readProfile : Profile version ok.");
+				cem_add_to_log(logmsg,J_LOG_DEBUG);
+				g_free(logmsg);
 			
-			// Free existing
-			if(password_hash) g_free(password_hash);
+				// Extract salt
+				salt = (guchar*)g_malloc(sizeof(guchar*) * AES_SALT_LENGTH);
+				memset(salt,0,AES_SALT_LENGTH);
+				*(guint32*)&salt[0] = *(guint32*)&contents[1];
+				*(guint32*)&salt[sizeof(guint32)] = *(guint32*)&contents[sizeof(guint32)+1];
 			
-			// Extract password hash
-			password_hash = (guchar*)g_malloc(sizeof(guchar*) * (SHA_HASH_LENGTH + 1));
-			memset(password_hash,0,SHA_HASH_LENGTH + 1);
-			g_memmove(password_hash,&contents[AES_SALT_LENGTH],SHA_HASH_LENGTH);
+				// Free existing
+				if(password_hash) g_free(password_hash);
 			
-			// Free existing
-			if(profile_hash) g_free(profile_hash);
+				// Extract password hash
+				password_hash = (guchar*)g_malloc(sizeof(guchar*) * (SHA_HASH_LENGTH + 1));
+				memset(password_hash,0,SHA_HASH_LENGTH + 1);
+				g_memmove(password_hash,&contents[AES_SALT_LENGTH + 1],SHA_HASH_LENGTH);
 			
-			// Extract profile hash
-			profile_hash = (guchar*)g_malloc(sizeof(guchar*) * (SHA_HASH_LENGTH + 1));
-			memset(profile_hash,0,SHA_HASH_LENGTH + 1);
-			g_memmove(profile_hash,&contents[AES_SALT_LENGTH + SHA_HASH_LENGTH],SHA_HASH_LENGTH);
+				// Free existing
+				if(profile_hash) g_free(profile_hash);
 			
-			// Free existing
-			if(encrypted_profile) g_free(encrypted_profile);
+				// Extract profile hash
+				profile_hash = (guchar*)g_malloc(sizeof(guchar*) * (SHA_HASH_LENGTH + 1));
+				memset(profile_hash,0,SHA_HASH_LENGTH + 1);
+				g_memmove(profile_hash,&contents[AES_SALT_LENGTH + SHA_HASH_LENGTH + 1],SHA_HASH_LENGTH);
 			
-			// Extract encrypted profile
-			encrypted_profile_size = length - SHA_HASH_LENGTH - SHA_HASH_LENGTH - AES_SALT_LENGTH;
-			encrypted_profile = (guchar*)g_malloc(sizeof(guchar*) * (encrypted_profile_size));
-			memset(encrypted_profile,0,encrypted_profile_size);
-			g_memmove(encrypted_profile,&contents[AES_SALT_LENGTH + SHA_HASH_LENGTH + SHA_HASH_LENGTH],encrypted_profile_size);
+				// Free existing
+				if(encrypted_profile) g_free(encrypted_profile);
+			
+				// Extract encrypted profile
+				encrypted_profile_size = length - SHA_HASH_LENGTH - SHA_HASH_LENGTH - AES_SALT_LENGTH - 1;
+				encrypted_profile = (guchar*)g_malloc(sizeof(guchar*) * (encrypted_profile_size));
+				memset(encrypted_profile,0,encrypted_profile_size);
+				g_memmove(encrypted_profile,&contents[AES_SALT_LENGTH + SHA_HASH_LENGTH + SHA_HASH_LENGTH + 1],encrypted_profile_size);
 	
-			// copy the username
-			if(loadeduser) g_free(loadeduser);
-			loadeduser = g_strdup(username);
+				// copy the username
+				if(loadeduser) g_free(loadeduser);
+				loadeduser = g_strdup(username);
 
-			profileloaded = TRUE;
+				profileloaded = TRUE;
+			}
 		}
 	}
 	else
@@ -577,14 +606,14 @@ gint StorageAgent::readProfile(gchar* username)
 		logmsg = g_strdup_printf("StorageAgent::readProfile : Profile for user %s doesn't exist.", username);
 		cem_add_to_log(logmsg,J_LOG_ERROR);
 		g_free(logmsg);
-		g_free(filename);
-		g_free(profilefile);
+		if(filename) g_free(filename);
+		if(profilefile) g_free(profilefile);
 		return 2;
 	}
   
-	g_free(contents);
-	g_free(filename);
-	g_free(profilefile);
+	if(contents) g_free(contents);
+	if(filename) g_free(filename);
+	if(profilefile) g_free(profilefile);
 
 	return 0;
 }
@@ -595,11 +624,12 @@ gint StorageAgent::writeProfile(gchar* username)
 {
 	gchar* profilefile = g_strjoin(NULL,username,PROFILE_FILE_EXT,NULL);
 	gchar* filename = g_build_filename(configure_get_jammo_directory(),JAMMOPROFILE,profilefile,NULL);
-	guint length = AES_SALT_LENGTH + SHA_HASH_LENGTH + SHA_HASH_LENGTH + encrypted_profile_size;
+	guint length = sizeof(guint8) + AES_SALT_LENGTH + SHA_HASH_LENGTH + SHA_HASH_LENGTH + encrypted_profile_size;
 	GError* error = NULL;
 	gchar* logmsg = NULL;
 	
 	/* Profile file will contain (in order, size in bytes)
+	*  version 1
 	*  salt 8
 	*  h(pass) 32
 	*  h(profile) 32
@@ -611,19 +641,22 @@ gint StorageAgent::writeProfile(gchar* username)
 	if(profile_hash == NULL) return 4;
 	if(encrypted_profile == NULL) return 5;
 	if(encrypted_profile_size == 0) return 6;
-	
+	if(version != JAMMO_PROFILE_VERSION) return 7;	
 	
 	gchar* content = (gchar*)g_malloc(sizeof(gchar*) * length);
 	memset(content,0,length);
 	
+	// Set version
+	*(guint8*)&content[0] = version;
+	
 	// Set salt
-	*(guint32*)&content[0] = *(guint32*)&salt[0];
-	*(guint32*)&content[sizeof(guint32)] = *(guint32*)&salt[sizeof(guint32)];
+	*(guint32*)&content[1] = *(guint32*)&salt[0];
+	*(guint32*)&content[sizeof(guint32) + 1] = *(guint32*)&salt[sizeof(guint32)];
 	
 	// Set password hash
-	g_memmove(&content[AES_SALT_LENGTH],password_hash,SHA_HASH_LENGTH);
-	g_memmove(&content[AES_SALT_LENGTH + SHA_HASH_LENGTH],profile_hash,SHA_HASH_LENGTH);
-	g_memmove(&content[AES_SALT_LENGTH + SHA_HASH_LENGTH + SHA_HASH_LENGTH],encrypted_profile,encrypted_profile_size);
+	g_memmove(&content[AES_SALT_LENGTH + 1],password_hash,SHA_HASH_LENGTH);
+	g_memmove(&content[AES_SALT_LENGTH + SHA_HASH_LENGTH + 1],profile_hash,SHA_HASH_LENGTH);
+	g_memmove(&content[AES_SALT_LENGTH + SHA_HASH_LENGTH + SHA_HASH_LENGTH + 1],encrypted_profile,encrypted_profile_size);
 	
 	// Check for previous profile file
 	if(g_file_test(filename,(G_FILE_TEST_EXISTS)))
