@@ -129,7 +129,7 @@ gint gems_communication_search_jammos()
 		}
 
 		// Go through list
-		for(iterator = ph_c_new_device_iterator(list); ph_c_device_iterator_is_last(iterator,list) != TRUE; ph_c_device_iterator_next_iterator(iterator))
+		for( ; ph_c_device_iterator_is_last(iterator,list) != TRUE; ph_c_device_iterator_next_iterator(iterator))
 		{
 			// Get the device
 			MAbstractDevice* dev = ph_c_device_iterator_get_device(iterator);
@@ -141,7 +141,7 @@ gint gems_communication_search_jammos()
 				{
 					if(gems_communication_establish_connection(dev) == TRUE)
 					{
-							logmsg = g_strdup_printf("gems_communication_search_jammos: Connected to new JamMo enabled device %s/%d",
+							logmsg = g_strdup_printf("gems_communication_search_jammos: Connected to new JamMo enabled device %s/%u",
 								ph_c_device_get_name(dev),ph_c_device_get_checksum(dev));
 							cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 							g_free(logmsg);
@@ -168,6 +168,7 @@ gint gems_communication_search_jammos()
 gboolean gems_communication_establish_connection(MAbstractDevice* device)
 {
 	gchar* logmsg = NULL;
+	gboolean rval = FALSE;
 	gems_components* data = gems_get_data();
 	
 	MAbstractConnection* conn = NULL;
@@ -183,18 +184,19 @@ gboolean gems_communication_establish_connection(MAbstractDevice* device)
 
 			if(gems_communication_write_data(ph_c_connection_get_fd(conn),msg) != msg->length)
 			{
-				logmsg = g_strdup_printf("gems_communication_gems_communication_establish_connection: Error writing CONNECT_REQ to JamMo service");
-				cem_add_to_log(logmsg, J_LOG_ERROR);
+				logmsg = g_strdup_printf("gems_communication_establish_connection: Error writing CONNECT_REQ to JamMo service on %s/%u",
+					ph_c_connection_get_remote_address(conn),ph_c_connection_get_device_checksum(conn));
+				cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
 				
 				data->connection_errorlist = gems_connection_error_add(data->connection_errorlist,ph_c_device_get_checksum(device), ERROR_CONNECTION);
 				ph_c_connection_delete(conn); // disconnects and deletes
 				conn = NULL;
-				return FALSE;
+				rval = FALSE;
 			}
 			else
 			{
-				logmsg = g_strdup_printf("gems_communication_gems_communication_establish_connection: Wrote CONNECT_REQ to JamMo service in %s",
+				logmsg = g_strdup_printf("gems_communication_establish_connection: Wrote CONNECT_REQ to JamMo service in %s",
 					ph_c_connection_get_remote_address(conn));
 				cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
@@ -206,19 +208,21 @@ gboolean gems_communication_establish_connection(MAbstractDevice* device)
 				// New item in JAMMO_WAITING_REQUEST state
 				gems_connection* new_item = gems_new_gems_connection(conn, 0, 0, JAMMO_WAITING_REQUEST, 0);
 				data->communication->connecting = g_list_append(data->communication->connecting, new_item);
-				return TRUE;
+				rval = TRUE;
 			}
+			gems_clear_message(msg);
+			return rval;
 		}
 		else
 		{
 			data->connection_errorlist = gems_connection_error_add(data->connection_errorlist,ph_c_device_get_checksum(device), ERROR_CONNECTION);
-			return FALSE;
+			return rval; // by default rval = FALSE
 		}
 	}
 	else
 	{
 		//printf("gems_communication_establish_connection: timer has not passed");
-		return FALSE;
+		return rval; // by default rval = FALSE
 	}
 }
 
@@ -257,8 +261,9 @@ gint gems_communication_retrieve_profiles()
 
 					if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE, element, request) == FALSE)
 					{
-						logmsg = g_strdup_printf("gems_communication_retrieve_profiles: cannot write GET_PROFILE_PUB");
-						cem_add_to_log(logmsg, J_LOG_ERROR);
+						logmsg = g_strdup_printf("gems_communication_retrieve_profiles: cannot write GET_PROFILE_PUB to %s/%u",
+							ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
+						cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 						ph_c_connection_disconnect(element->connection);
 						cleanup_required = TRUE;
@@ -331,8 +336,9 @@ gint gems_communication_request_groups()
 
 						if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE, element, request) == FALSE)
 						{
-							logmsg = g_strdup_printf("gems_communication_request_groups: cannot write REQUEST_GROUP_INFO");
-							cem_add_to_log(logmsg, J_LOG_ERROR);
+							logmsg = g_strdup_printf("gems_communication_request_groups: cannot write REQUEST_GROUP_INFO to %s/%u",
+								ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
+							cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 							g_free(logmsg);
 							ph_c_connection_disconnect(element->connection);
 							cleanup_required = TRUE;
@@ -415,9 +421,9 @@ gint gems_communication_advert_group()
 				{					
 					if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE, element, msg) == FALSE)
 					{
-						gchar* logmsg = g_strdup_printf("gems_communication_advert_group: cannot send OFFER_GROUP to device %d with user %d",
+						gchar* logmsg = g_strdup_printf("gems_communication_advert_group: cannot send OFFER_GROUP to device %u with user %u",
 							ph_c_connection_get_device_checksum(element->connection), element->profile->id);
-						cem_add_to_log(logmsg, J_LOG_ERROR);
+						cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 						// TODO add error handling - add connection error to errorlist
 					}
@@ -462,7 +468,7 @@ gint gems_communication_sanitize_grouplist()
 			if(g_timer_elapsed(info->group_advert_timer,NULL) > GROUP_REMOVE_LIMIT)
 			{
 				gchar* logmsg = g_strdup_printf("Group %u is past remove limit (%f elapsed), removing.",info->id, g_timer_elapsed(info->group_advert_timer,NULL));
-				cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
+				cem_add_to_log(logmsg, J_LOG_DEBUG);
 				g_free(logmsg);
 				
 				GList* tempiter = iterator;
@@ -571,14 +577,14 @@ void print_group(gems_group_info* info)
 	for(i = 0; i < (GROUP_MAX_SIZE - 1); i++)	printf("(%d)\t%u\n",i,members[i]);
 }
 
-gint gems_communication_already_connected(int checksum)
+gint gems_communication_already_connected(guint checksum)
 {
 	gems_components* data = gems_get_data();
 	
 	if(data == NULL)
 	{
 		gchar* logmsg = g_strdup_printf("gems_communication_already_connected: data == NULL");
-		cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
+		cem_add_to_log(logmsg, J_LOG_ERROR);
 		g_free(logmsg);
 		return NOT_IN_LIST;	
 	}
@@ -595,7 +601,7 @@ gint gems_communication_already_connected(int checksum)
 	return NOT_IN_LIST;
 }
 
-gboolean gems_communication_search_from_list(GList* list, int checksum)
+gboolean gems_communication_search_from_list(GList* list, guint checksum)
 {
 	GList* iterator = NULL;
 	if(g_list_length(list) == 0) return FALSE;
@@ -616,7 +622,7 @@ gboolean gems_communication_search_from_list(GList* list, int checksum)
 	return FALSE;
 }
 
-gems_connection* gems_communication_get_connection(GList* list, int checksum)
+gems_connection* gems_communication_get_connection(GList* list, guint checksum)
 {
 	GList* iterator = NULL;
 	if(g_list_length(list) == 0) return NULL; // empty
@@ -660,7 +666,8 @@ void gems_communication_process_new(gems_connection* element)
 {
 	gems_communication_data* data = gems_get_data()->communication;
 	data->connections = g_list_append(data->connections, element);
-	gchar* logmsg = g_strdup_printf("gems_communication_process_new: added new");
+	gchar* logmsg = g_strdup_printf("gems_communication_process_new: added new (%s/%u)",
+		ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
 	cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 	g_free(logmsg);
 }
@@ -670,7 +677,8 @@ void gems_communication_process_new_rejected(gems_connection* element)
 	gems_communication_data* data = gems_get_data()->communication;
 	gems_connection_set_action(element); // Record the time this connection was rejected
 	data->rejected = g_list_append(data->rejected, element);
-	gchar* logmsg = g_strdup_printf("gems_communication_process_new_rejected: added new element to rejected list");
+	gchar* logmsg = g_strdup_printf("gems_communication_process_new_rejected: added new element (%s/%u) to rejected list",
+		ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
 	cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 	g_free(logmsg);
 }
@@ -763,7 +771,7 @@ gint gems_communication_process_connected()
 						case -1:
 						default:
 							logmsg = g_strdup_printf("gems_communication_process_list: length not read correctly (bytesread = %d). Disconnecting", bytesread);
-							cem_add_to_log(logmsg, J_LOG_ERROR);
+							cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 							g_free(logmsg);
 							ph_c_connection_disconnect(element->connection);
 							if(do_teacher_check) teacher_cleanup_required = TRUE;
@@ -789,7 +797,7 @@ gint gems_communication_process_connected()
 						case -1:
 						default:
 							logmsg = g_strdup_printf("gems_communication_process_list : command not read correctly (bytesread = %d). Disconnecting", bytesread);
-							cem_add_to_log(logmsg, J_LOG_ERROR);
+							cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 							g_free(logmsg);
 							
 							ph_c_connection_disconnect(element->connection);
@@ -826,7 +834,7 @@ gint gems_communication_process_connected()
 					else
 					{
 						logmsg = g_strdup_printf("gems_communication_process_list : error reading rest of data (%d), disconnecting", bytesread);
-						cem_add_to_log(logmsg, J_LOG_ERROR);
+						cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 						
 						ph_c_connection_disconnect(element->connection);
@@ -850,7 +858,7 @@ gint gems_communication_process_connected()
 				if(gems_connection_partial_data_amount(element) > ntohl(gems_connection_get_32(element,sizeof(guint16))))
 				{					
 					logmsg = g_strdup_printf("gems_communication_process_list: more than full packet! ERROR?");
-					cem_add_to_log(logmsg, J_LOG_ERROR);
+					cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 					
 					ph_c_connection_disconnect(element->connection);
@@ -905,8 +913,9 @@ gint gems_communication_process_connected()
 								gems_message* err = gems_create_error_message(ERROR_INVALID_SERVICE_ID_TYPE, AA_SERVICE_ID);
 								if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
 								{
-									logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_INVALID_SERVICE_ID");
-									cem_add_to_log(logmsg, J_LOG_ERROR);
+									logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_INVALID_SERVICE_ID (%s/%u)",
+										ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
+									cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 									g_free(logmsg);
 								}
 								gems_clear_message(err);
@@ -921,8 +930,9 @@ gint gems_communication_process_connected()
 					case 0:
 					case -1:
 					default:
-						logmsg = g_strdup_printf("gems_communication_process_list: service id read error(%d)", bytesread);
-						cem_add_to_log(logmsg, J_LOG_ERROR);
+						logmsg = g_strdup_printf("gems_communication_process_list: service id read error (%d) from %s/%u", bytesread,
+							ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
+						cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 						ph_c_connection_disconnect(element->connection);
 						if(do_teacher_check) teacher_cleanup_required = TRUE;
@@ -1011,10 +1021,12 @@ gboolean gems_communication_process_data(gems_connection* element)
 	
 	gems_connection_localize_data_in_buffer(element);
 	
-	logmsg = g_strdup_printf("gems_communication_process_data: element contains: [%d|%d|%d]",
+	logmsg = g_strdup_printf("gems_communication_process_data: element contains: [%d|%u|%d] from %s/%u",
 		gems_connection_get_16(element,0),
 		gems_connection_get_32(element,2),
-		gems_connection_get_16(element,6));
+		gems_connection_get_16(element,6),
+		ph_c_connection_get_remote_address(element->connection),
+		ph_c_connection_get_device_checksum(element->connection));
 	cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 	g_free(logmsg);
 	
@@ -1029,8 +1041,9 @@ gboolean gems_communication_process_data(gems_connection* element)
 			err = gems_create_error_message(ERROR_SERVICE_NOT_RUNNING_TYPE, AA_SERVICE_ID);
 			if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
 			{
-				logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING");
-				cem_add_to_log(logmsg, J_LOG_ERROR);
+				logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING to %s/%u",
+					ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
+				cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
 			}
 			gems_clear_message(err);
@@ -1045,8 +1058,9 @@ gboolean gems_communication_process_data(gems_connection* element)
 					err = gems_create_error_message(ERROR_INVALID_ACCESS_TYPE, TEACHER_PROFILE_SERVICE_ID);
 					if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
 					{
-						logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_INVALID_ACCESS_TYPE");
-						cem_add_to_log(logmsg, J_LOG_ERROR);
+						logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_INVALID_ACCESS_TYPE to %s/%u",
+							ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
+						cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 					}
 					gems_clear_message(err);
@@ -1062,8 +1076,9 @@ gboolean gems_communication_process_data(gems_connection* element)
 					err = gems_create_error_message(ERROR_SERVICE_NOT_RUNNING_TYPE, PROFILE_SERVICE_ID);
 					if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
 					{
-						logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING");
-						cem_add_to_log(logmsg, J_LOG_ERROR);
+						logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING to %s/%u",
+							ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
+						cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 					}
 					gems_clear_message(err);
@@ -1082,8 +1097,9 @@ gboolean gems_communication_process_data(gems_connection* element)
 				err = gems_create_error_message(ERROR_SERVICE_NOT_RUNNING_TYPE, GROUP_SERVICE_ID);
 				if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
 				{
-					logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING");
-					cem_add_to_log(logmsg, J_LOG_ERROR);
+					logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING to %s/%u",
+						ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
+					cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 				}
 				gems_clear_message(err);
@@ -1098,7 +1114,8 @@ gboolean gems_communication_process_data(gems_connection* element)
 				err = gems_create_error_message(ERROR_SERVICE_NOT_RUNNING_TYPE, COLLABORATION_SERVICE_ID);
 				if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
 				{
-					logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING");
+					logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING, to %s/%u",
+						ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
 					cem_add_to_log(logmsg, J_LOG_ERROR);
 					g_free(logmsg);
 				}
@@ -1114,7 +1131,8 @@ gboolean gems_communication_process_data(gems_connection* element)
 				err = gems_create_error_message(ERROR_SERVICE_NOT_RUNNING_TYPE, CONTROL_SERVICE_ID);
 				if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
 				{
-					logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING");
+					logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING to %s/%u",
+						ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
 					cem_add_to_log(logmsg, J_LOG_ERROR);
 					g_free(logmsg);
 				}
@@ -1131,7 +1149,8 @@ gboolean gems_communication_process_data(gems_connection* element)
 				err = gems_create_error_message(ERROR_SERVICE_NOT_RUNNING_TYPE, MENTOR_SERVICE_ID);
 				if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
 				{
-					logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING");
+					logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING to %s/%u",
+						ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
 					cem_add_to_log(logmsg, J_LOG_ERROR);
 					g_free(logmsg);
 				}
@@ -1162,8 +1181,9 @@ gboolean gems_communication_process_data(gems_connection* element)
 			err = gems_create_error_message(ERROR_INVALID_SERVICE_ID_TYPE, JAMMO_SERVICE_ID);
 			if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
 			{
-				logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_INVALID_SERVICE_ID");
-				cem_add_to_log(logmsg, J_LOG_ERROR);
+				logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_INVALID_SERVICE_ID to %s/%u",
+					ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
+				cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
 			}
 			gems_clear_message(err);
@@ -1220,7 +1240,7 @@ void gems_communication_process_error(gems_connection* element)
 											if(gems_get_data()->teacher_profile_request_timer) g_timer_destroy(gems_get_data()->teacher_profile_request_timer);
 											gems_unset_waiting_profile_from_teacher();
 										
-											cem_add_to_log("gems_communication_process_error: No profile for requested username on teacher server",J_LOG_NETWORK_DEBUG);
+											cem_add_to_log("gems_communication_process_error: No profile for requested username on teacher server",J_LOG_NETWORK);
 										
 											// TODO add callback to CHUM : profile not found
 										}
@@ -1263,7 +1283,7 @@ void gems_communication_process_error(gems_connection* element)
 										if(element->profile->id == gems_group_get_owner(NULL))
 										{
 											logmsg = g_strdup_printf("gems_communication_process_error: processing ERROR_GROUP_NOT_ACTIVE, sent by owner, group is being reset.");
-											cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
+											cem_add_to_log(logmsg,J_LOG_NETWORK);
 											g_free(logmsg);
 										
 											// TODO notify chum through callback
@@ -1284,7 +1304,7 @@ void gems_communication_process_error(gems_connection* element)
 											else
 											{
 												logmsg = g_strdup_printf("gems_communication_process_error: processing ERROR_GROUP_NOT_ACTIVE, no connection to group owner");
-												cem_add_to_log(logmsg,J_LOG_ERROR);
+												cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 												g_free(logmsg);
 											}
 										}
@@ -1336,7 +1356,7 @@ void gems_communication_process_error(gems_connection* element)
 									if(owner_elem == NULL) // Not found
 									{
 										logmsg = g_strdup_printf("gems_communication_process_error: processing ERROR_ALREADY_IN_GROUP, no connection to group owner");
-										cem_add_to_log(logmsg,J_LOG_ERROR);
+										cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 										g_free(logmsg);
 										break;
 									}
@@ -1349,7 +1369,7 @@ void gems_communication_process_error(gems_connection* element)
 										if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE, owner_elem, msg) == FALSE)
 										{
 											logmsg = g_strdup_printf("gems_communication_process_error: processing ERROR_ALREADY_IN_GROUP, cannot write REQUEST_MEMBERS to group owner");
-											cem_add_to_log(logmsg,J_LOG_ERROR);
+											cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 											g_free(logmsg);
 										}
 						
@@ -1396,7 +1416,7 @@ void gems_communication_process_error(gems_connection* element)
 									if(owner_elem == NULL)
 									{
 										logmsg = g_strdup_printf("gems_communication_process_error: processing ERROR_NOT_GROUP_OWNER, no connection to group owner");
-										cem_add_to_log(logmsg,J_LOG_NETWORK);
+										cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 										g_free(logmsg);
 									}
 									else
@@ -1496,8 +1516,8 @@ gint gems_communication_probe_for_peerhood()
 	
 	if(data == NULL) return FALSE;
 	
-	gchar* logmsg = g_strdup_printf("gems_networking_probe_for_peerhood");
-	cem_add_to_log(logmsg,J_LOG_INFO);
+	gchar* logmsg = g_strdup_printf("gems_communication_probe_for_peerhood");
+	cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 	g_free(logmsg);
 	
 	// Initialize callback if it was not set (PeerHood not found at start)
@@ -1509,8 +1529,8 @@ gint gems_communication_probe_for_peerhood()
 	// Cannot get instance - should not happen
 	if(data->ph == NULL)
 	{
-		logmsg = g_strdup_printf("gems_networking_probe_for_peerhood: Got PeerHood NULL reference.");
-		cem_add_to_log(logmsg,J_LOG_ERROR);
+		logmsg = g_strdup_printf("gems_communication_probe_for_peerhood: Got PeerHood NULL reference.");
+		cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 		g_free(logmsg);
 		return TRUE; // Got NULL reference, try again
 	}
@@ -1522,7 +1542,7 @@ gint gems_communication_probe_for_peerhood()
 		gems_register_services();
 		gems_enable_network_timeout_functions();
 		logmsg = g_strdup_printf("gems_networking_probe_for_peerhood: initialized and re-enabled timeout functions.");
-		cem_add_to_log(logmsg,J_LOG_INFO);
+		cem_add_to_log(logmsg,J_LOG_NETWORK);
 		g_free(logmsg);
 		g_free(args);
 		return FALSE; // Got connection, remove
@@ -1530,7 +1550,7 @@ gint gems_communication_probe_for_peerhood()
 	else
 	{
 		logmsg = g_strdup_printf("gems_networking_probe_for_peerhood: cannot initialize peerhood.");
-		cem_add_to_log(logmsg,J_LOG_INFO);
+		cem_add_to_log(logmsg,J_LOG_NETWORK);
 		g_free(logmsg);
 		g_free(args);
 		return TRUE;
@@ -1546,13 +1566,13 @@ void gems_communication_peerhood_close_detected()
 	if(data == NULL) return;
 	
 	logmsg = g_strdup_printf("gems_networking_peerhood_close_detected.");
-	cem_add_to_log(logmsg,J_LOG_INFO);
+	cem_add_to_log(logmsg,J_LOG_NETWORK);
 	g_free(logmsg);
 	
 	if(data->ph == NULL)
 	{
 		logmsg = g_strdup_printf("gems_networking_peerhood_close_detected: PeerHood NULL.");
-		cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
+		cem_add_to_log(logmsg,J_LOG_NETWORK);
 		g_free(logmsg);
 	}
 	else
@@ -1616,7 +1636,7 @@ gboolean gems_teacher_connection_disconnect()
 		data->timeout_functions[9] = g_timeout_add_full(G_PRIORITY_HIGH,100,(GSourceFunc)gems_communication_search_teacher, NULL, NULL);
 		
 		gchar* logmsg = g_strdup_printf("gems_teacher_connection_disconnect: connection to teacher was disconnected. Teacher search re-enabled.");
-		cem_add_to_log(logmsg,J_LOG_DEBUG);
+		cem_add_to_log(logmsg,J_LOG_NETWORK);
 		g_free(logmsg);
 		
 		return TRUE;
@@ -1638,7 +1658,7 @@ void gems_clear_teacher_connection()
 		data->teacher_connection->connection = NULL;
 		
 		gchar* logmsg = g_strdup_printf("gems_clear_teacher_connection: connection to teacher was disconnected");
-		cem_add_to_log(logmsg,J_LOG_DEBUG);
+		cem_add_to_log(logmsg,J_LOG_NETWORK);
 		g_free(logmsg);
 	}
 	
@@ -1652,7 +1672,11 @@ gboolean gems_communication_do_profile_request_to_teacher(gchar* username)
 	gboolean rval = TRUE;
 	gems_message* msg = gems_create_message_teacher_service_profile_request(username);
 	if(gems_teacher_connection_is_connected()) rval = gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE,gems_get_teacher_connection()->connection,msg);
-	else rval = FALSE;
+	else
+	{
+		cem_add_to_log("No connection to teacher. Cannot send profile request.",J_LOG_NETWORK);
+		rval = FALSE;
+	}
 	gems_clear_message(msg);
 	
 	return rval;
@@ -1665,9 +1689,14 @@ gboolean gems_communication_send_profile_to_teacher()
 		gems_message* msg = gems_create_message_service_profile(PROFILE_FULL);
 		gboolean rval = gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE,gems_get_teacher_connection()->connection,msg);
 		gems_clear_message(msg);
+		if(rval == FALSE) cem_add_to_log("Cannot send profile to teacher, writing failed",J_LOG_NETWORK_DEBUG);
 		return rval;
 	}
-	else return FALSE;
+	else
+	{
+		cem_add_to_log("No connection to teacher. Cannot send profile",J_LOG_NETWORK);
+		return FALSE;
+	}
 }
 
 gint gems_communication_search_teacher()
@@ -1685,7 +1714,7 @@ gint gems_communication_search_teacher()
 	if(list == NULL)
 	{
 		logmsg = g_strdup_printf("gems_communication_search_teacher: connection to PeerHood daemon was lost.");
-		cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
+		cem_add_to_log(logmsg, J_LOG_NETWORK);
 		g_free(logmsg);
 		gems_communication_peerhood_close_detected();
 		return FALSE;
@@ -1703,7 +1732,7 @@ gint gems_communication_search_teacher()
 		}
 		
 		// Go through list - there should be only one teacher
-		for(iterator = ph_c_new_device_iterator(list); ph_c_device_iterator_is_last(iterator,list) != TRUE; ph_c_device_iterator_next_iterator(iterator))
+		for( ; ph_c_device_iterator_is_last(iterator,list) != TRUE; ph_c_device_iterator_next_iterator(iterator))
 		{
 			// Get the device
 			MAbstractDevice* dev = ph_c_device_iterator_get_device(iterator);
@@ -1717,7 +1746,7 @@ gint gems_communication_search_teacher()
 					// set connection
 					gems_get_teacher_connection()->connection = gems_new_gems_connection(conn, 0, 0, JAMMO_CONNECTED_NO_AUTH, 0);
 					
-					logmsg = g_strdup_printf("gems_communication_search_jammos: Connected to new teacher device %s/%d",
+					logmsg = g_strdup_printf("gems_communication_search_teacher: Connected to new teacher device %s/%u",
 						ph_c_device_get_name(dev),ph_c_device_get_checksum(dev));
 					cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
