@@ -293,7 +293,7 @@ void jammo_gems_init(int argc, char* argv[])
 	else
 	{
 		logmsg = g_strdup_printf("NO PEERHOOD RUNNING - NETWORKING DISABLED");
-		cem_add_to_log(logmsg,J_LOG_DEBUG);
+		cem_add_to_log(logmsg,J_LOG_NETWORK);
 		g_free(logmsg);
 		
 		components->service_jammo->enabled = FALSE;
@@ -575,13 +575,15 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 					
 				if(gems_communication_write_data(ph_c_connection_get_fd(aConnection),err) != err->length)
 				{
-					logerror = g_strdup_printf("gems_ph_callback_newconnection: cannot write ERROR_SERVICE_NOT_RUNNING (%s)",JAMMO_SERVICE_NAME);
-					cem_add_to_log(logerror,J_LOG_ERROR);
+					logerror = g_strdup_printf("gems_ph_callback_newconnection: cannot write ERROR_SERVICE_NOT_RUNNING (%s) to %s/%u",
+						JAMMO_SERVICE_NAME, ph_c_connection_get_remote_address(aConnection),ph_c_connection_get_device_checksum(aConnection));
+					cem_add_to_log(logerror,J_LOG_NETWORK_DEBUG);
 					g_free(logerror);
 				}
 				else
 				{
-					logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_SERVICE_NOT_RUNNING (%s) to %s",JAMMO_SERVICE_NAME, ph_c_connection_get_remote_address(aConnection));
+					logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_SERVICE_NOT_RUNNING (%s) to %s/%u",
+						JAMMO_SERVICE_NAME, ph_c_connection_get_remote_address(aConnection),ph_c_connection_get_device_checksum(aConnection));
 					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 				}
@@ -601,13 +603,15 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 					
 				if(gems_communication_write_data(ph_c_connection_get_fd(aConnection),err) != err->length)
 				{
-					logerror = g_strdup_printf("gems_ph_callback_newconnection: cannot write ERROR_SERVICE_NOT_RUNNING (%s)", COLLABORATION_SERVICE_NAME);
-					cem_add_to_log(logerror,J_LOG_ERROR);
+					logerror = g_strdup_printf("gems_ph_callback_newconnection: cannot write ERROR_SERVICE_NOT_RUNNING (%s) to %s/%u",
+						COLLABORATION_SERVICE_NAME, ph_c_connection_get_remote_address(aConnection),ph_c_connection_get_device_checksum(aConnection));
+					cem_add_to_log(logerror,J_LOG_NETWORK_DEBUG);
 					g_free(logerror);
 				}
 				else
 				{
-					logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_SERVICE_NOT_RUNNING (%s) to %s",COLLABORATION_SERVICE_NAME, ph_c_connection_get_remote_address(aConnection));
+					logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_SERVICE_NOT_RUNNING (%s) to %s/%u",
+						COLLABORATION_SERVICE_NAME, ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
 					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 				}
@@ -627,13 +631,15 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 					
 				if(gems_communication_write_data(ph_c_connection_get_fd(aConnection),err) != err->length)
 				{
-					logerror = g_strdup_printf("gems_ph_callback_newconnection: cannot write ERROR_SERVICE_NOT_RUNNING (%s)", CONTROL_SERVICE_NAME);
-					cem_add_to_log(logerror,J_LOG_ERROR);
+					logerror = g_strdup_printf("gems_ph_callback_newconnection: cannot write ERROR_SERVICE_NOT_RUNNING (%s) to %s/%u", 
+						CONTROL_SERVICE_NAME, ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
+					cem_add_to_log(logerror,J_LOG_NETWORK_DEBUG);
 					g_free(logerror);
 				}
 				else
 				{
-					logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_SERVICE_NOT_RUNNING (%s) to %s",CONTROL_SERVICE_NAME, ph_c_connection_get_remote_address(aConnection));
+					logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_SERVICE_NOT_RUNNING (%s) to %s/%u",
+						CONTROL_SERVICE_NAME, ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
 					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 				}
@@ -661,20 +667,23 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 				
 						if(gems_communication_write_data(ph_c_connection_get_fd(aConnection),err) != err->length)
 						{
-							logerror = g_strdup_printf("gems_ph_callback_newconnection: cannot write ERROR_CONNECTION_REJECTED (%s)", CONTROL_SERVICE_NAME);
-							cem_add_to_log(logerror,J_LOG_ERROR);
+							logerror = g_strdup_printf("gems_ph_callback_newconnection: cannot write ERROR_CONNECTION_REJECTED (%s) to \"TEACHER\" (%s/%u)", 
+								CONTROL_SERVICE_NAME, ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
+							cem_add_to_log(logerror,J_LOG_NETWORK_DEBUG);
 							g_free(logerror);
 						}
 						else
 						{
-							logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_CONNECTION_REJECTED (%s) to TEACHER %s",CONTROL_SERVICE_NAME, ph_c_connection_get_remote_address(aConnection));
+							logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_CONNECTION_REJECTED (%s) to \"TEACHER\" %s/%u",
+								CONTROL_SERVICE_NAME, ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
 							cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 							g_free(logmsg);
 						}
 						
 						gems_clear_message(err);
 						
-						logmsg = g_strdup_printf("gems_ph_callback_newconnection: TEACHER CONNECTED from %s, TEACHER is already connected!", ph_c_connection_get_remote_address(aConnection));
+						logmsg = g_strdup_printf("gems_ph_callback_newconnection: Connection to %s from %s/%u, TEACHER is already connected!",
+							CONTROL_SERVICE_NAME, ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
 						cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 						
@@ -689,7 +698,8 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 		// Invalid port
 		else
 		{
-			logmsg = g_strdup_printf("gems_ph_callback_newconnection: connecting to wrong port (connecting port %d)", aPort);
+			logmsg = g_strdup_printf("gems_ph_callback_newconnection: %s/%u connecting to wrong port (connecting port %u)", 
+				ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection), aPort);
 			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 			g_free(logmsg);
 			
@@ -697,13 +707,15 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 				
 			if(gems_communication_write_data(ph_c_connection_get_fd(aConnection),err) != err->length)
 			{
-				logerror = g_strdup_printf("gems_ph_callback_newconnection: cannot write ERROR_CONNECTION_REJECTED");
-				cem_add_to_log(logerror,J_LOG_ERROR);
+				logerror = g_strdup_printf("gems_ph_callback_newconnection: cannot write ERROR_CONNECTION_REJECTED to %s/%u",
+					ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
+				cem_add_to_log(logerror,J_LOG_NETWORK_DEBUG);
 				g_free(logerror);
 			}
 			else
 			{
-				logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_CONNECTION_REJECTED to %s", ph_c_connection_get_remote_address(aConnection));
+				logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_CONNECTION_REJECTED to %s/%u", 
+					ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
 				cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
 			}
@@ -716,7 +728,8 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 		// Not in any list - new connection
 		if((isconnected = gems_communication_already_connected(ph_c_connection_get_device_checksum(aConnection))) == NOT_IN_LIST)
 		{
-			logmsg = g_strdup_printf("gems_ph_callback_newconnection: Adding a connection with cid %d address %s..", aConnectionId, ph_c_connection_get_remote_address(aConnection));
+			logmsg = g_strdup_printf("gems_ph_callback_newconnection: Adding a connection with cid %d, address %s and checksum %u", 
+				aConnectionId, ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
 			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 			g_free(logmsg);
 		
@@ -725,17 +738,14 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 		
 			// Add to initialized list
 			components->initialized_connections = g_list_append(components->initialized_connections,(init_connection));
-		
-			logmsg = g_strdup_printf("gems_ph_callback_newconnection: new connection added to list");
-			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
-			g_free(logmsg);
 			
 			// Connection success, remove from errors. If no such device in the list, nothing is done
 			components->connection_errorlist = gems_connection_error_remove(components->connection_errorlist,ph_c_connection_get_device_checksum(aConnection));
 		}
 		else if(isconnected == IN_REJECTED_LIST)
 		{
-			logmsg = g_strdup_printf("gems_ph_callback_newconnection: connection is in rejected list");
+			logmsg = g_strdup_printf("gems_ph_callback_newconnection: connection to %s/%u is in rejected list", 
+				ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
 			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 			g_free(logmsg);
 			
@@ -744,17 +754,20 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 			switch(gems_communication_write_data(ph_c_connection_get_fd(aConnection),message))
 			{
 				case -1:
-					logerror = g_strdup_printf("gems_ph_callback_newconnection: Cannot write error ERROR_CONNECTION_REJECTED");
-					cem_add_to_log(logerror,J_LOG_ERROR);
+					logerror = g_strdup_printf("gems_ph_callback_newconnection: Cannot write error ERROR_CONNECTION_REJECTED to %s/%u",
+						ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
+					cem_add_to_log(logerror,J_LOG_NETWORK_DEBUG);
 					g_free(logerror);
 					break;
 				case 0:
-					logerror = g_strdup_printf("gems_ph_callback_newconnection: Wrote nothing");
-					cem_add_to_log(logerror,J_LOG_ERROR);
+					logerror = g_strdup_printf("gems_ph_callback_newconnection: Wrote nothing to %s/%u",
+						ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
+					cem_add_to_log(logerror,J_LOG_NETWORK_DEBUG);
 					g_free(logerror);
 					break;
 				default:
-					logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_CONNECTION_REJECTED message data to %s", ph_c_connection_get_remote_address(aConnection));
+					logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_CONNECTION_REJECTED message data to %s/%u",
+						ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
 					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 					break;
@@ -785,7 +798,8 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 								if(gems_group_is_in_group(element->profile->id) == TRUE) // In our group
 								{
 									element->game_connection = aConnection; // Add as game connection
-									logmsg = g_strdup_printf("gems_ph_callback_newconnection: Added Game connection for Collaboration");
+									logmsg = g_strdup_printf("gems_ph_callback_newconnection: Added Game connection for Collaboration (%s/%u)",
+										ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
 									cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 									g_free(logmsg);
 									return;
@@ -793,18 +807,18 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 								// Not in our group - disconnect
 								else
 								{
-									logerror = g_strdup_printf("gems_ph_callback_newconnection: Connection from %s/%d to %s who is not in the same group, disconnecting.", 
+									logerror = g_strdup_printf("gems_ph_callback_newconnection: Connection from %s/%u to %s who is not in the same group, disconnecting.", 
 									ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection), COLLABORATION_SERVICE_NAME);
-									cem_add_to_log(logerror,J_LOG_ERROR);
+									cem_add_to_log(logerror,J_LOG_NETWORK_DEBUG);
 									g_free(logerror);
 									
 									err = gems_create_error_message(ERROR_NOT_IN_GROUP_TYPE,COLLABORATION_SERVICE_ID);
 		
 									if(gems_communication_write_data(ph_c_connection_get_fd(aConnection),err) != err->length)
 									{
-										logerror = g_strdup_printf("gems_ph_callback_newconnection: error sending ERROR_NOT_IN_GROUP to %s/%d",
+										logerror = g_strdup_printf("gems_ph_callback_newconnection: error sending ERROR_NOT_IN_GROUP to %s/%u",
 											ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
-										cem_add_to_log(logerror,J_LOG_ERROR);
+										cem_add_to_log(logerror,J_LOG_NETWORK_DEBUG);
 										g_free(logerror);
 									}
 									gems_clear_message(err);
@@ -816,9 +830,9 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 							else
 							{
 								// TODO error - no profile
-								logerror = g_strdup_printf("gems_ph_callback_newconnection: Connection from %s/%d to %s - no profile retrieved yet, disconnecting.", 
+								logerror = g_strdup_printf("gems_ph_callback_newconnection: Connection from %s/%u to %s - no profile retrieved yet, disconnecting.", 
 								ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection), COLLABORATION_SERVICE_NAME);
-								cem_add_to_log(logerror,J_LOG_ERROR);
+								cem_add_to_log(logerror,J_LOG_NETWORK_DEBUG);
 								g_free(logerror);
 							
 								ph_c_connection_delete(aConnection);
@@ -829,18 +843,18 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 					else
 					{
 						//error - group not active
-						logerror = g_strdup_printf("gems_ph_callback_newconnection: Connection from %s/%d to %s when group was not active.", 
+						logerror = g_strdup_printf("gems_ph_callback_newconnection: Connection from %s/%u to %s when group was not active.", 
 						ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection), COLLABORATION_SERVICE_NAME);
-						cem_add_to_log(logerror,J_LOG_ERROR);
+						cem_add_to_log(logerror,J_LOG_NETWORK_DEBUG);
 						g_free(logerror);
 					
 						err = gems_create_error_message(ERROR_GROUP_NOT_ACTIVE_TYPE,COLLABORATION_SERVICE_ID);
 
 						if(gems_communication_write_data(ph_c_connection_get_fd(aConnection),err) != err->length)
 						{
-							logerror = g_strdup_printf("gems_ph_callback_newconnection: error sending ERROR_GROUP_NOT_ACTIVE to %s/%d",
+							logerror = g_strdup_printf("gems_ph_callback_newconnection: error sending ERROR_GROUP_NOT_ACTIVE to %s/%u",
 								ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
-							cem_add_to_log(logerror,J_LOG_ERROR);
+							cem_add_to_log(logerror,J_LOG_NETWORK_DEBUG);
 							g_free(logerror);
 						}
 
@@ -853,7 +867,8 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 			}
 			
 			// Otherwise already connected, send error
-			logmsg = g_strdup_printf("gems_ph_callback_newconnection: device is already connected");
+			logmsg = g_strdup_printf("gems_ph_callback_newconnection: device (%s/%u) is already connected",
+				ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
 			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 			g_free(logmsg);
 			
@@ -862,17 +877,20 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 			switch(gems_communication_write_data(ph_c_connection_get_fd(aConnection),message))
 			{
 				case -1:
-					logerror = g_strdup_printf("gems_ph_callback_newconnection: Cannot write error ERROR_ALREADY_CONNECTED");
-					cem_add_to_log(logerror,J_LOG_ERROR);
+					logerror = g_strdup_printf("gems_ph_callback_newconnection: Cannot write error ERROR_ALREADY_CONNECTED to %s/%u",
+						ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
+					cem_add_to_log(logerror,J_LOG_NETWORK_DEBUG);
 					g_free(logerror);
 					break;
 				case 0:
-					logerror = g_strdup_printf("gems_ph_callback_newconnection: Wrote nothing");
-					cem_add_to_log(logerror,J_LOG_ERROR);
+					logerror = g_strdup_printf("gems_ph_callback_newconnection: Wrote nothing to %s/%u",
+						ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
+					cem_add_to_log(logerror,J_LOG_NETWORK_DEBUG);
 					g_free(logerror);
 					break;
 				default:
-					logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_ALREADY_CONNECTED message data to %s", ph_c_connection_get_remote_address(aConnection));
+					logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_ALREADY_CONNECTED message data to %s/%u", 
+						ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
 					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 					break;
@@ -923,7 +941,8 @@ gint gems_process_connections()
 			{
 				ph_c_connection_disconnect(element->connection);
 				cleanup_required = TRUE;
-				logmsg = g_strdup_printf("gems_process_connections: Disconnected/error, received %d bytes.", length);
+				logmsg = g_strdup_printf("gems_process_connections: Disconnected/error, received %d bytes from %s/%u.",
+					length, ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 			}
 			// Read size does not match
 			else if(length != sizeof(type))
@@ -934,9 +953,10 @@ gint gems_process_connections()
 			// New devices will have to verify version first from JamMo service - errors are also handled in JamMo service
 			else if(ntohs(type) == JAMMO_SERVICE_ID || ntohs(type) == ERROR_MSG)
 			{
-					if(ntohs(type) == JAMMO_SERVICE_ID)	logmsg = g_strdup_printf("gems_process_connections: got JAMMO_SERVICE_ID from \"%s\"", 
-						ph_c_connection_get_remote_address(element->connection));
-					else logmsg = g_strdup_printf("gems_process_connections: got ERROR_MSG from \"%s\"", ph_c_connection_get_remote_address(element->connection));
+					if(ntohs(type) == JAMMO_SERVICE_ID)	logmsg = g_strdup_printf("gems_process_connections: got JAMMO_SERVICE_ID from %s/%u", 
+						ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
+					else logmsg = g_strdup_printf("gems_process_connections: got ERROR_MSG from from %s/%u", 
+						ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 					
 					if(data->service_jammo->enabled == TRUE)
 					{	
@@ -967,7 +987,8 @@ gint gems_process_connections()
 						gems_message* err = gems_create_error_message(ERROR_SERVICE_NOT_RUNNING_TYPE, JAMMO_SERVICE_ID);
 						
 						if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
-							logerror = g_strdup_printf("gems_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING");
+							logerror = g_strdup_printf("gems_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING to %s/%u", 
+								ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 							
 						gems_clear_message(err);
 					
@@ -977,13 +998,15 @@ gint gems_process_connections()
 			}
 			else
 			{
-					logmsg = g_strdup_printf("Invalid service id \"%d\" from %s", type, ph_c_connection_get_remote_address(element->connection));
+					logmsg = g_strdup_printf("Invalid service id \"%d\" from %s/%u", type, ph_c_connection_get_remote_address(element->connection), 
+						ph_c_connection_get_device_checksum(element->connection));
 					
 					// Send error
 					gems_message* err = gems_create_error_message(ERROR_INVALID_SERVICE_ID_TYPE, JAMMO_SERVICE_ID);
 	
 					if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
-						logerror = g_strdup_printf("gems_process_connections: cannot write ERROR_INVALID_SERVICE_ID");
+						logerror = g_strdup_printf("gems_process_connections: cannot write ERROR_INVALID_SERVICE_ID to %s/%u", 
+							ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 
 					gems_clear_message(err);
 					
@@ -1000,7 +1023,7 @@ gint gems_process_connections()
 		
 		if(logerror != NULL)
 		{
-			cem_add_to_log(logerror,J_LOG_ERROR);
+			cem_add_to_log(logerror,J_LOG_NETWORK_DEBUG);
 			g_free(logerror);
 			logerror = NULL;
 		}
@@ -1010,8 +1033,10 @@ gint gems_process_connections()
 	}
 	// Do cleanup of disconnected connections
 	if(cleanup_required == TRUE) data->initialized_connections = gems_cleanup_connections_from_list(data->initialized_connections);
-	
+
+#ifdef DEBUG
 	gems_connection_debugging(data);
+#endif
 	
 	return TRUE;
 	//logmsg = g_strdup_printf("Done processing connections");
@@ -1180,7 +1205,7 @@ void gems_init_peerhood_callback()
 	gems_get_data()->ph_cb = ph_c_create_callback(notify, newconnection,(void*)gems_get_data(),(void*)gems_get_data());
 	
 	gchar* logmsg = g_strdup_printf("gems_networking_init_peerhood_callback: new callback created.");
-	cem_add_to_log(logmsg,J_LOG_INFO);
+	cem_add_to_log(logmsg,J_LOG_DEBUG);
 	g_free(logmsg);
 }
 
