@@ -56,10 +56,13 @@ gems_message* gems_create_error_message(guint16 errortype, guint16 serviceid)
 
 void gems_clear_message(gems_message* message)
 {
-	if(message->message != NULL) g_free(message->message);
-	message->message = NULL;
-	if(message != NULL) g_free(message);
-	message = NULL;
+	if(message != NULL)
+	{
+		if(message->message != NULL) g_free(message->message);
+		message->message = NULL;
+		g_free(message);
+		message = NULL;
+	}
 }
 
 gchar* get_errormessage(guint16 errortype)
@@ -231,6 +234,7 @@ gems_message* gems_create_message_service_profile(guint16 type)
 	position = position + sizeof(guint32);
 	
 	if(type == PROFILE_PUB) return msg;
+	if(type == CONTROL_REPLY_LOGIN) return msg;
 	// add full profile info
 	else if(type == PROFILE_FULL)
 	{
@@ -1021,6 +1025,30 @@ gems_message* gems_create_message_control_set_login_name(gchar* username)
 	return msg;
 }
 
+gems_message* gems_create_message_control_get_login()
+{
+	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	guint position = 0;
+	
+	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16);
+	
+	msg->message = (gchar*)g_malloc0(sizeof(gchar*) * msg->length);
+	
+	// Service id 16 bits
+	*(guint16*)&msg->message[position] = g_htons(CONTROL_SERVICE_ID);
+	position = position + sizeof(guint16);
+	
+	// Length 32 bits
+	*(guint32*)&msg->message[position] = g_htonl(msg->length);
+	position = position + sizeof(guint32);
+	
+	// Command 16 bits
+	*(guint16*)&msg->message[position] = g_htons(CONTROL_GET_LOGIN);
+	position = position + sizeof(guint16);
+	
+	return msg;
+}
+
 gems_message* gems_create_message_mentor_log_message(guint16 type, char *message)
 {
 	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
@@ -1028,9 +1056,7 @@ gems_message* gems_create_message_mentor_log_message(guint16 type, char *message
 	
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + strlen(message) + 1;
 	
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
-	
-	memset(msg->message,'\0',msg->length);
+	msg->message = (gchar*)g_malloc0(sizeof(gchar*) * msg->length);
 	
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(MENTOR_SERVICE_ID);
@@ -1051,3 +1077,27 @@ gems_message* gems_create_message_mentor_log_message(guint16 type, char *message
 
 
 }
+
+gems_message* gems_create_general_message(gems_message* msg, guint16 serviceid, guint32 length, guint16 type)
+{
+	if(msg == NULL) msg = (gems_message*)g_malloc(sizeof(gems_message));
+	guint position = 0;
+	
+	if(length == 0) msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16);
+	else msg->length = length;
+	
+	msg->message = (gchar*)g_malloc0(sizeof(gchar*) * msg->length);
+	
+	// Service id 16 bits
+	*(guint16*)&msg->message[position] = g_htons(serviceid);
+	position = position + sizeof(guint16);
+	
+	// Length 32 bits
+	*(guint32*)&msg->message[position] = g_htonl(msg->length);
+	position = position + sizeof(guint32);
+	
+	// Command 16 bits
+	*(guint16*)&msg->message[position] = g_htons(type);
+	
+	return msg;
+}
