@@ -54,6 +54,9 @@ gems_message* gems_create_message_collaboration_action_slider_series(guint16 typ
 gems_message* gems_create_message_control_mode(guint16 type, guint16 cntrl_type, guint16 lock_mode);
 gems_message* gems_create_message_control_ok(guint16 type);
 gems_message* gems_create_message_control_set_login_name(gchar* username);
+gems_message* gems_create_message_control_get_login();
 
 gems_message* gems_create_message_mentor_log_message(guint16 type, char *message);
+
+gems_message* gems_create_general_message(gems_message* msg, guint16 serviceid, guint32 length, guint16 type);
 #endif // __GEMS_MESSAGE_FUNCTIONS
