@@ -107,7 +107,7 @@ gint gems_profile_manager_authenticate_user(gchar* username, gchar* passworddata
 	// verify passwords
 	if(!gems_security_verify_hash(pwhash,profilemanager_storage_get_password_hash(pm),SHA_HASH_LENGTH))
 	{
-		cem_add_to_log("Authentication failure: invalid password", J_LOG_INFO);
+		cem_add_to_log("Authentication failure: invalid password", J_LOG_ERROR);
 		if(passwd != NULL) g_free(passwd);
 		if(pwhash != NULL) g_free(pwhash);
 		gems_security_clear_security();
@@ -165,7 +165,6 @@ gint gems_profile_manager_authenticate_user(gchar* username, gchar* passworddata
 
 gint gems_profile_manager_set_user(gchar* username)
 {
-	cem_add_to_log("gems_profile_manager_set_user",J_LOG_INFO);
 	// if authenticated, cannot change user before logout, logout clears also the loaded data and sets load check to FALSE
 	if(profilemanager_is_authenticated(gems_get_profile_manager())) return CHANGE_USER_LOGOUT_REQUIRED;
 	else 
@@ -346,30 +345,34 @@ gboolean gems_profile_manager_change_password(gchar* passworddata)
 					}
 				}
 				
-				// TODO Send passhash + encnewpw to teacher if teacher is present
-				if(gems_security_verify_hash(newpass_hash,newpass_dechash,SHA_HASH_LENGTH))
+				if(gems_profile_manager_get_profile_type() == PROF_TYPE_REMOTE)
 				{
-					if(gems_teacher_connection_is_connected())
+					// Send passhash + encnewpw to teacher if teacher is present
+					if(gems_security_verify_hash(newpass_hash,newpass_dechash,SHA_HASH_LENGTH))
 					{
-						if(newpasslen > G_MAXUINT8) cem_add_to_log("Password length is more than max for guint8!.",J_LOG_ERROR);
-						
-						gems_message *pwcmsg = gems_create_message_password_changed(newpass_hash,newpass_enc,pwdatalen,(guint8)newpasslen);
-						if(pwcmsg)
+						if(gems_teacher_connection_is_connected())
 						{
-							if(!gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE,gems_get_teacher_connection()->connection,pwcmsg))
+							// TODO check this earlier and react
+							if(newpasslen > G_MAXUINT8) cem_add_to_log("Password length is more than max for guint8!.",J_LOG_ERROR);
+						
+							gems_message *pwcmsg = gems_create_message_password_changed(newpass_hash,newpass_enc,pwdatalen,(guint8)newpasslen);
+							if(pwcmsg)
 							{
-								cem_add_to_log("Password change cannot be sent. Invalid write.",J_LOG_ERROR);
-								// TODO resend?
+								if(!gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE,gems_get_teacher_connection()->connection,pwcmsg))
+								{
+									cem_add_to_log("Password change cannot be sent. Invalid write.",J_LOG_ERROR);
+									// TODO resend?
+								}
+								else cem_add_to_log("Password change sent succesfully!",J_LOG_DEBUG);
+								gems_clear_message(pwcmsg);
 							}
-							else cem_add_to_log("Password change sent succesfully!",J_LOG_INFO);
-							gems_clear_message(pwcmsg);
 						}
-					}
-					// TODO If no teacher, the encnewpw (+ its length) should be saved somewhere for sending it later!
-					else cem_add_to_log("Password change cannot be sent, no teacher present.",J_LOG_INFO);
+						// TODO If no teacher, the encnewpw (+ its length) should be saved somewhere for sending it later!
+						else cem_add_to_log("Password change cannot be sent, no teacher present.",J_LOG_DEBUG);
 					
+					}
+					else cem_add_to_log("Errors while creating password to be sent to teacher, hashes do not match.",J_LOG_ERROR);
 				}
-				else cem_add_to_log("Errors while creating password to be sent to teacher, hashes do not match.",J_LOG_ERROR);
 				
 			}
 			else
@@ -417,19 +420,23 @@ gboolean gems_profile_manager_create_default_user_profile(gchar* passworddata, g
 	GRand* grand = g_rand_new_with_seed(time(NULL));
 	
 	// Create profile with default informationm, except id (random), password (given) and age (given)
-	jammo_profile_container* profile = gems_teacher_server_create_profile(g_rand_int(grand),"defaultuser",passworddata,"none","FirstName","LastName",age,PROF_DEFAULT_AVATARID);
+	jammo_profile_container* profile = gems_teacher_server_create_profile(PROF_TYPE_LOCAL,g_rand_int(grand),"defaultuser",passworddata,"none","FirstName","LastName",age,PROF_DEFAULT_AVATARID);
 
 	if(profile)
 	{
 		if(gems_teacher_server_write_profile(profile) != WRITE_OK)
 		{
-			cem_add_to_log("Cannot create profile for user \"defaultuser\"", J_LOG_DEBUG);
+			cem_add_to_log("Cannot create profile for user \"defaultuser\", profile cannot be written.", J_LOG_ERROR);
 			rval = FALSE;
 		}
 		else cem_add_to_log("Created profile for user \"defaultuser\"", J_LOG_DEBUG);
 		gems_teacher_server_clear_profile_container(profile);
 	}
-	else rval = FALSE;
+	else
+	{
+		cem_add_to_log("Cannot initialize profile for user \"defaultuser\", profile cannot be created!",J_LOG_ERROR);
+		rval = FALSE;
+	}
 	
 	g_free(grand);
 	return rval;
@@ -446,8 +453,12 @@ gboolean gems_profile_manager_logout()
 	// Saving and updating can be done as authenticated
 	if(profilemanager_is_authenticated(pm))
 	{
-		// Send profile to teacher
-		if(gems_communication_send_profile_to_teacher()) cem_add_to_log("Profile updated to teacher server",J_LOG_DEBUG);
+		// Send profile to teacher if it is remote profile
+		if(gems_profile_manager_get_profile_type() == PROF_TYPE_REMOTE)
+		{
+			if(gems_communication_send_profile_to_teacher()) cem_add_to_log("Profile updated to teacher server.",J_LOG_DEBUG);
+			else cem_add_to_log("Profile was not updated to teacher.", J_LOG_DEBUG);
+		}
 		
 		// Is it necessary to save profile
 		if(profilemanager_is_saving_required(pm))
@@ -633,3 +644,19 @@ gchar* gems_profile_manager_get_loaded_username()
 	
 	return profilemanager_get_loaded_username(pm);
 }
+
+guint8 gems_profile_manager_get_profile_type()
+{
+	ProfileManager* pm = gems_get_data()->pm;
+	if(pm == NULL) return 0;
+	
+	return profilemanager_get_profile_type(pm);
+}
+
+guint8 gems_profile_manager_get_profile_version()
+{
+	ProfileManager* pm = gems_get_data()->pm;
+	if(pm == NULL) return 0;
+	
+	return profilemanager_get_profile_version(pm);
+}
