@@ -127,7 +127,28 @@ gboolean gems_profile_manager_remove_points(guint32 _value);
 /* Reset points (set to zero) */
 void gems_profile_manager_reset_points();
 
+/* Check if user is authenticated
+ *
+ * Returns: TRUE if authenticated
+ */
 gboolean gems_profile_manager_is_authenticated();
+
+/* Returns the username whose profile is currently loaded
+ *
+ * Returns: username
+ */
 gchar* gems_profile_manager_get_loaded_username();
 
+/* Returns the profile type (PROF_TYPE_LOCAL or PROF_TYPE_REMOTE)
+ * 
+ * Returns: PROF_TYPE_LOCAL or PROF_TYPE_REMOTE or 0 if errors.
+ */
+guint8 gems_profile_manager_get_profile_type();
+
+/* Returns the version of this profile
+ * 
+ * Returns: profile version as single integer
+ */
+guint8 gems_profile_manager_get_profile_version();
+
 #endif
