@@ -19,7 +19,7 @@
 #include "gems_structures.h"
 
 
-gems_message* gems_security_create_envelope(gint16 type,gems_connection* element, gems_message* original);
+gems_message* gems_security_create_envelope(guint16 type,gems_connection* element, gems_message* original);
 
 gint gems_security_extract_envelope(gems_connection* element);
 
