@@ -42,6 +42,8 @@ gboolean gems_service_control_process_request(gems_connection* element)
 					case CONTROL_SET_LOGIN:
 						gems_service_control_handle_set_login(data,element);
 						break;
+					case CONTROL_GET_LOGIN:
+						gems_service_control_handle_get_login(data,element);
 					default:
 						break;
 				}
@@ -168,3 +170,16 @@ void gems_service_control_handle_set_login(gems_components* data, gems_connectio
 	}
 	g_free(loginname);
 }
+
+void gems_service_control_handle_get_login(gems_components* data, gems_connection* element)
+{
+	gems_message* msg = gems_create_message_service_profile(CONTROL_REPLY_LOGIN);
+	
+	// not logged in, msg is NULL -> create a general message with basic header only
+	if(msg == NULL) msg = gems_create_general_message(NULL,PROFILE_SERVICE_ID,0,CONTROL_REPLY_LOGIN);
+		
+	if(!gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE,element,msg))
+		cem_add_to_log("gems_service_control_handle_get_login: cannot write login name reply as public profile to teacher",J_LOG_NETWORK_DEBUG);
+	else cem_add_to_log("gems_service_control_handle_get_login: wrote login name reply to teacher", J_LOG_NETWORK_DEBUG);
+
+}
