@@ -60,8 +60,9 @@ gboolean gems_service_profile_process_request(gems_connection* element)
 					// Send
 					if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE,element,profilemsg) == FALSE)
 					{
-						logmsg = g_strdup_printf("gems_service_profile_process_request: cannot write PROFILE_PUB");
-						cem_add_to_log(logmsg,J_LOG_ERROR);
+						logmsg = g_strdup_printf("gems_service_profile_process_request: cannot write PROFILE_PUB to %s/%u",
+							ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
+						cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 					}
 					// Free message
@@ -147,7 +148,7 @@ gboolean gems_service_profile_process_request(gems_connection* element)
 			if(element->profile == NULL) element->profile = gems_new_peer_profile(uname,uid,age,aid);
 			else gems_peer_profile_set_values(element->profile,uname,uid,age,aid);
 			
-			logmsg = g_strdup_printf("gems_service_profile_process_request: Got profile:\n\tId:\t%u\n\tName:\t%s\n\tAge:\t%d\n\tAvtr:\t%u",
+			logmsg = g_strdup_printf("gems_service_profile_process_request: Got profile, [Id:%u|Name:%s|Age:%d|Avtr:%u]",
 				element->profile->id,element->profile->username,element->profile->age,element->profile->avatarid);
 			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 			g_free(logmsg);
@@ -200,7 +201,7 @@ gboolean gems_service_profile_process_profile_upload(gems_connection* element)
 				// if logged in with same username, do not allow!
 				if(gems_profile_manager_is_authenticated() && g_strcmp0(username,gems_profile_manager_get_username(NULL)) == 0)
 				{
-					cem_add_to_log("Got profile from teacher for user who has already logged in, discarding profile",J_LOG_DEBUG);
+					cem_add_to_log("Got profile from teacher for user who has already logged in, discarding profile.",J_LOG_DEBUG);
 				}
 				else
 				{
