@@ -72,7 +72,7 @@ void gems_clear_gems_connection(gems_connection* element)
 		
 		if(ph_c_connection_disconnect(element->connection) == TRUE)
 		{
-			logmsg = g_strdup_printf("Disconnected device %d", ph_c_connection_get_device_checksum(element->connection));
+			logmsg = g_strdup_printf("Disconnected device %s/%u", ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 			g_free(logmsg);
 		}
@@ -83,7 +83,7 @@ void gems_clear_gems_connection(gems_connection* element)
 	{
 		if(ph_c_connection_disconnect(element->game_connection) == TRUE)
 		{
-			logmsg = g_strdup_printf("Disconnected game connection");
+			logmsg = g_strdup_printf("Disconnected game connection to %s/%u", ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 			g_free(logmsg);
 		}
@@ -131,18 +131,21 @@ gems_connection* gems_new_gems_connection(MAbstractConnection* newconn,
 // Clear the networking buffer
 void gems_connection_clear_buffer(gems_connection* element)
 {
+	if(element == NULL) return;
 	memset(&element->nwbuffer,'\0',JAMMO_NETWORK_BUFFER_MAX_SIZE);
 	element->add_position = 0;
 }
 
 void gems_connection_set_action(gems_connection* element)
 {
+	if(element == NULL) return;
 	if(element->last_action == NULL) element->last_action = g_timer_new();
 	else g_timer_start(element->last_action);
 }
 
 double gems_connection_get_last_action(gems_connection* element)
 {
+	if(element == NULL) return 0.0;
 	// Wasn't set, set now
 	if(element->last_action == NULL) gems_connection_set_action(element);
 	return g_timer_elapsed(element->last_action,NULL);
@@ -151,6 +154,8 @@ double gems_connection_get_last_action(gems_connection* element)
 // Add 16bit integer to network buffer
 void gems_connection_add_16(gems_connection* element, guint16 value)
 {
+	if(element == NULL) return;
+	
 	// TODO report / handle if buffer exceeded
 	if((element->add_position + sizeof(guint16)) >= JAMMO_NETWORK_BUFFER_MAX_SIZE) return;
 	
@@ -161,6 +166,8 @@ void gems_connection_add_16(gems_connection* element, guint16 value)
 // Add 32bit integer to network buffer
 void gems_connection_add_32(gems_connection* element, guint32 value)
 {
+	if(element == NULL) return;
+	
 	// TODO report / handle if buffer exceeded
 	if((element->add_position + sizeof(guint32)) >= JAMMO_NETWORK_BUFFER_MAX_SIZE) return;
 	
@@ -171,6 +178,8 @@ void gems_connection_add_32(gems_connection* element, guint32 value)
 // Add 64bit integer to network buffer
 void gems_connection_add_64(gems_connection* element, guint64 value)
 {
+	if(element == NULL) return;
+	
 	// TODO report / handle if buffer exceeded
 	if((element->add_position + sizeof(guint64)) >= JAMMO_NETWORK_BUFFER_MAX_SIZE) return;
 	
@@ -182,6 +191,8 @@ void gems_connection_add_64(gems_connection* element, guint64 value)
 // it will not sent anymore
 void gems_connection_add_float(gems_connection* element, gfloat value)
 {
+	if(element == NULL) return;
+	
 	// TODO report / handle if buffer exceeded
 	if((element->add_position + sizeof(gfloat)) >= JAMMO_NETWORK_BUFFER_MAX_SIZE) return;
 	
@@ -192,6 +203,8 @@ void gems_connection_add_float(gems_connection* element, gfloat value)
 // Add characters to network buffer, define need for padding with last value (pad)
 void gems_connection_add_char(gems_connection* element, gchar* value, guint length, gboolean pad)
 {
+	if(element == NULL || value == NULL) return;
+	
 	// TODO report / handle if buffer exceeded
 	if((element->add_position + length) >= JAMMO_NETWORK_BUFFER_MAX_SIZE) return;
 	
@@ -205,6 +218,8 @@ void gems_connection_add_char(gems_connection* element, gchar* value, guint leng
 // Add padding - a NULL character
 void gems_connection_add_padding(gems_connection* element)
 {
+	if(element == NULL) return;
+	
 	if((element->add_position + 1) >= JAMMO_NETWORK_BUFFER_MAX_SIZE) return;
 	
 	element->nwbuffer[element->add_position] = '\0';
@@ -214,6 +229,8 @@ void gems_connection_add_padding(gems_connection* element)
 // Add data to the end of nwbuffer
 void gems_connection_add_data(gems_connection* element, gchar* data, guint length)
 {
+	if(element == NULL || data == NULL) return;
+	
 	if(element->add_position + length >= JAMMO_NETWORK_BUFFER_MAX_SIZE) return;
 	
 	memcpy(&element->nwbuffer[element->add_position],data,length);
@@ -223,6 +240,8 @@ void gems_connection_add_data(gems_connection* element, gchar* data, guint lengt
 // Get 16 bit integer from position
 guint16 gems_connection_get_16(gems_connection* element, guint from)
 {
+	if(element == NULL) return 0;
+	
 	if(from > element->add_position) return 0;
 	
 	return *(guint16*)&element->nwbuffer[from];
@@ -231,6 +250,8 @@ guint16 gems_connection_get_16(gems_connection* element, guint from)
 // Get 32 bit integer from position
 guint32 gems_connection_get_32(gems_connection* element, guint from)
 {
+	if(element == NULL) return 0;
+	
 	if(from > element->add_position) return 0;
 	
 	return *(guint32*)&element->nwbuffer[from];
@@ -239,6 +260,8 @@ guint32 gems_connection_get_32(gems_connection* element, guint from)
 // Get 64 bit integer from position
 guint64 gems_connection_get_64(gems_connection* element, guint from)
 {
+	if(element == NULL) return 0;
+	
 	if(from > element->add_position) return 0;
 	
 	return *(guint64*)&element->nwbuffer[from];
@@ -247,6 +270,8 @@ guint64 gems_connection_get_64(gems_connection* element, guint from)
 // Get 32 bit float from position
 gfloat gems_connection_get_float_for_localization(gems_connection* element, guint from)
 {
+	if(element == NULL) return 0;
+	
 	gfloat ret;
 	guint32 value;
 
@@ -262,6 +287,8 @@ gfloat gems_connection_get_float_for_localization(gems_connection* element, guin
 // Get 32 bit float from position
 gfloat gems_connection_get_float(gems_connection* element, guint from)
 {
+	if(element == NULL) return 0;
+	
 	gfloat value;
 
 	if(from > element->add_position) return 0;
@@ -274,6 +301,8 @@ gfloat gems_connection_get_float(gems_connection* element, guint from)
 // Get characters from position until next NULL character
 gchar* gems_connection_get_char(gems_connection* element, guint from)
 {
+	if(element == NULL) return NULL;
+	
 	// TODO do a real check - copy until \0 character is found !
 	return (gchar*)&element->nwbuffer[from];
 }
@@ -281,6 +310,8 @@ gchar* gems_connection_get_char(gems_connection* element, guint from)
 // Get data as chars from position until lenght is reached. Returns new gchar pointer, remember to free.
 gchar* gems_connection_get_data(gems_connection* element, guint from, guint length)
 {
+	if(element == NULL) return NULL;
+	
 	gchar* buffer = (gchar*)g_malloc(sizeof(gchar*)*length);
 	memset(buffer,'\0',length);
 
@@ -292,6 +323,8 @@ gchar* gems_connection_get_data(gems_connection* element, guint from, guint leng
 // Copies the content in newcontent to nwbuffer of element
 void gems_connection_set_content(gems_connection* element, gchar* newcontent, guint length)
 {
+	if(element == NULL) return;
+	
 	gems_connection_clear_buffer(element);
 	memcpy(&element->nwbuffer,newcontent,length);
 }
@@ -299,12 +332,15 @@ void gems_connection_set_content(gems_connection* element, gchar* newcontent, gu
 // Get the amount of partial data in the buffer
 guint gems_connection_partial_data_amount(gems_connection* element)
 {
+	if(element == NULL) return 0;
 	return element->add_position;
 }
 
 // Clear all disconnected gems_connection elements from list
 GList* gems_cleanup_connections_from_list(GList* list)
 {
+	if(list == NULL) return NULL;
+	
 	GList* iterator = g_list_first(list);
 	GList* tempiter = NULL;
 	
@@ -332,6 +368,8 @@ GList* gems_cleanup_connections_from_list(GList* list)
 
 gems_peer_profile* gems_new_peer_profile(gchar* username, guint32 id, guint16 age, guint32 avatarid)
 {
+	if(username == NULL) return NULL;
+	 
 	gems_peer_profile* profile = (gems_peer_profile*)g_malloc(sizeof(gems_peer_profile));
 	
 	profile->id = id;
@@ -344,6 +382,8 @@ gems_peer_profile* gems_new_peer_profile(gchar* username, guint32 id, guint16 ag
 
 void gems_peer_profile_set_values(gems_peer_profile* profile, gchar* username, guint32 id, guint16 age, guint32 avatarid)
 {
+	if(profile == NULL || username == NULL) return;
+	
 	profile->id = id;
 	profile->username = g_strdup(username);
 	profile->avatarid = avatarid;
@@ -361,6 +401,8 @@ void gems_clear_peer_profile(gems_peer_profile* profile)
 
 void gems_connection_localize_data_in_buffer(gems_connection* element)
 {
+	if(element == NULL) return;
+	
 	gchar* logmsg = NULL;
 	int temp_position = element->add_position;
 	// first 8 bytes should be always the same - even with error messages
@@ -377,7 +419,8 @@ void gems_connection_localize_data_in_buffer(gems_connection* element)
 			// TODO convert the error message (chars from 10->)
 			break;
 		case JAMMO_SERVICE_ID:
-			logmsg = g_strdup_printf("gems_connection_localize_data_in_buffer: got JAMMO_SERVICE_ID - should not happen!!");
+			logmsg = g_strdup_printf("gems_connection_localize_data_in_buffer: got JAMMO_SERVICE_ID from %s/%u - should not happen!!", 
+				ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 			g_free(logmsg);
 			break;
@@ -429,6 +472,17 @@ void gems_connection_localize_data_in_buffer(gems_connection* element)
 				case PROFILE_PASSCHANGED:
 					// Userid
 					gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element,element->add_position)));
+					break;
+				case CONTROL_REPLY_LOGIN:
+					// Username -> add_position = add_position + Username length + tailing '\0'
+					element->add_position = element->add_position + strlen(gems_connection_get_char(element,element->add_position)) + 1;
+					// User id
+					gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element,element->add_position)));
+					// age
+					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element,element->add_position)));
+					// avatar id
+					gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element,element->add_position)));
+					break;
 				default:
 					break;
 			}
@@ -551,6 +605,10 @@ void gems_connection_localize_data_in_buffer(gems_connection* element)
 					break;
 				case CONTROL_SET_LOGIN:
 					break;
+				case CONTROL_GET_LOGIN:
+					break;
+				case CONTROL_REPLY_LOGIN:
+					break;
 				default:
 					break;
 			}
@@ -587,7 +645,7 @@ GList* gems_connection_error_add(GList* list, guint device_checksum, guint error
 		item->connection_timer = g_timer_new();
 		g_timer_start(item->connection_timer);
 		list = g_list_prepend(list,item);
-		logmsg = g_strdup_printf("gems_connection_error_add: added new device %d, list = %d", item->checksum, g_list_length(list));
+		logmsg = g_strdup_printf("gems_connection_error_add: added new device %u, list length: %d", item->checksum, g_list_length(list));
 		cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 		g_free(logmsg);
 	}
@@ -609,7 +667,7 @@ GList* gems_connection_error_add(GList* list, guint device_checksum, guint error
 				break;
 		}
 		g_timer_start(item->connection_timer);
-		logmsg = g_strdup_printf("gems_connection_error_add: added to existing device %d (errors : %d)", item->checksum, item->connection_errors);
+		logmsg = g_strdup_printf("gems_connection_error_add: added to existing device %u (errors : %d)", item->checksum, item->connection_errors);
 		cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 		g_free(logmsg);
 	}
@@ -619,6 +677,7 @@ GList* gems_connection_error_add(GList* list, guint device_checksum, guint error
 gems_connection_error* gems_connection_error_get(GList* list, guint device_checksum)
 {
 	GList* iterator = NULL;
+	if(list == NULL) return NULL;
 	if(g_list_length(list) == 0) return NULL;
 	
 	// Search the list
@@ -696,7 +755,7 @@ GList* gems_connection_error_remove(GList* list, guint device_checksum)
 		// Match
 		if(element->checksum == device_checksum)
 		{
-			gchar* logmsg = g_strdup_printf("gems_connection_error_remove: removed %d",device_checksum);
+			gchar* logmsg = g_strdup_printf("gems_connection_error_remove: removed %u",device_checksum);
 			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 			g_free(logmsg);
 			
@@ -720,6 +779,8 @@ void gems_clear_connection_error(gems_connection_error* element)
 
 GList* gems_process_rejected(GList* list)
 {
+	if(list == NULL) return NULL;
+	
 	GList* iterator = g_list_first(list);
 	
 	while(iterator)
