@@ -20,6 +20,8 @@ jammo_profile_container* gems_teacher_server_new_profile_container()
 	// Allocation failed?
 	if(container == NULL) return NULL;
 	
+	container->type = 0;
+	container->version = JAMMO_PROFILE_VERSION;
 	container->userid = 0;
 	container->username = NULL;
 	container->password = NULL;
@@ -83,14 +85,14 @@ void gems_teacher_server_clear_profile_data_container(teacher_server_profile_dat
 	}	
 }
 
-jammo_profile_container* gems_teacher_server_create_profile(guint32 _userid, gchar* _username, gchar* _password,
+jammo_profile_container* gems_teacher_server_create_profile(guint8 _type, guint32 _userid, gchar* _username, gchar* _password,
 	gchar* _authlevel, gchar* _firstname, gchar* _lastname, guint16 _age, guint32 _avatarid)
 {
 	// Call setup function with NULL salt and 0 points, salt will be generated when NULL
-	return gems_teacher_server_setup_profile(_userid,_username,_password,NULL,_authlevel,_firstname,_lastname,_age,0,_avatarid);
+	return gems_teacher_server_setup_profile(_type, _userid,_username,_password,NULL,_authlevel,_firstname,_lastname,_age,0,_avatarid);
 }
 
-jammo_profile_container* gems_teacher_server_setup_profile(guint32 _userid, gchar* _username, gchar* _password,
+jammo_profile_container* gems_teacher_server_setup_profile(guint8 _type, guint32 _userid, gchar* _username, gchar* _password,
 	guchar* _salt, gchar* _authlevel, gchar* _firstname, gchar* _lastname, guint16 _age, guint32 _points, guint32 _avatarid)
 {
 	// check input
@@ -103,10 +105,12 @@ jammo_profile_container* gems_teacher_server_setup_profile(guint32 _userid, gcha
 	if(gems_check_illegal_characters(_authlevel)) return NULL;
 	if(gems_check_illegal_characters(_firstname)) return NULL;
 	if(gems_check_illegal_characters(_lastname)) return NULL;
+	if(_type < PROF_TYPE_LOCAL || _type > PROF_TYPE_REMOTE) return NULL;
 
 	jammo_profile_container* container = gems_teacher_server_new_profile_container();
 	
 	// Set details
+	container->type = _type;
 	container->userid = _userid;
 	container->age = _age;
 	container->points = _points;
@@ -168,6 +172,7 @@ gboolean gems_teacher_server_encrypt_profile(jammo_profile_container* container)
 {
 	// vars
 	guint encproflen = 0, hashlen = 0, profilelen = 0, passlen = 0;
+	gchar* type = NULL;
 	gchar* userid = NULL;
 	gchar* age = NULL;
 	gchar* points = NULL;
@@ -183,12 +188,17 @@ gboolean gems_teacher_server_encrypt_profile(jammo_profile_container* container)
 
 	if(container)
 	{
+		// Type out of range
+		if(container->type < PROF_TYPE_LOCAL || container->type > PROF_TYPE_REMOTE) return FALSE;
+		
 		// Set profile data
+		type = g_strdup_printf("%d",container->type);
 		userid = g_strdup_printf("%u",container->userid);
 		age = g_strdup_printf("%u",container->age);
 		points = g_strdup_printf("%u",container->points);
 		avatarid = g_strdup_printf("%u",container->avatarid);
-		profile = (guchar*)g_strjoin(",", userid, container->username, container->authlevel, container->firstname, container->lastname, points, age, avatarid, NULL);
+		profile = (guchar*)g_strjoin(",",type,userid, container->username, container->authlevel, 
+			container->firstname, container->lastname, points, age, avatarid, NULL);
 		profilelen = strlen((gchar*)profile)+1;
 	
 		// Create salt and password
@@ -219,23 +229,26 @@ gboolean gems_teacher_server_encrypt_profile(jammo_profile_container* container)
 		
 			if(gems_security_verify_hash(profilehash,decprofhash,SHA_HASH_LENGTH))
 			{
-				container->encrypted_length = AES_SALT_LENGTH + 32 + 32 + profilelen;
+				container->encrypted_length = 1 + AES_SALT_LENGTH + 32 + 32 + profilelen;
 				
 				// Allocate content, free old if it was allocated
 				if(container->encrypted != NULL) g_free(container->encrypted);
 				container->encrypted = (gchar*)g_malloc(sizeof(gchar*) * container->encrypted_length);
 				memset(container->encrypted,0,container->encrypted_length);
 	
+				// set into beginning
+				*(guint8*)&container->encrypted[0] = container->version;
+				
 				// Set salt
-				*(guint32*)&container->encrypted[0] = *(guint32*)&container->salt[0];
-				*(guint32*)&container->encrypted[sizeof(guint32)] = *(guint32*)&container->salt[sizeof(guint32)];
+				*(guint32*)&container->encrypted[1] = *(guint32*)&container->salt[0];
+				*(guint32*)&container->encrypted[sizeof(guint32)+1] = *(guint32*)&container->salt[sizeof(guint32)];
 	
 				// Set password hash
-				g_memmove(&container->encrypted[AES_SALT_LENGTH],passhash,32);
+				g_memmove(&container->encrypted[AES_SALT_LENGTH + 1],passhash,32);
 				// Set profile hash
-				g_memmove(&container->encrypted[AES_SALT_LENGTH + 32],profilehash,32);
+				g_memmove(&container->encrypted[AES_SALT_LENGTH + 32 + 1],profilehash,32);
 				// Set profile
-				g_memmove(&container->encrypted[AES_SALT_LENGTH + 64],encprofile,profilelen);
+				g_memmove(&container->encrypted[AES_SALT_LENGTH + 64 + 1],encprofile,profilelen);
 				
 			}
 			else rval = FALSE;
@@ -243,6 +256,7 @@ gboolean gems_teacher_server_encrypt_profile(jammo_profile_container* container)
 		else rval = FALSE;
 
 		// Free all
+		if(type != NULL) g_free(type);
 		if(userid != NULL) g_free(userid);
 		if(age != NULL) g_free(age);
 		if(points != NULL) g_free(points);
@@ -344,10 +358,10 @@ gchar* gems_teacher_server_serialize_all_profiles(GList* list, guint* length)
 		profile = (jammo_profile_container*)iter->data;
 		
 		// Calculate length for the huge gchar*
-		total_length = total_length + sizeof(guint32) + sizeof(guint8) + strlen(profile->username) + 1 + 
-			sizeof(guint8) + strlen(profile->password) + 1 + AES_SALT_LENGTH + sizeof(guint8) + 
-			strlen(profile->firstname) + 1 + sizeof(guint8) + strlen(profile->lastname) + 1 +sizeof(guint8) + 
-			strlen(profile->authlevel) + 1 + sizeof(guint16) + sizeof(guint32) + sizeof(guint32);
+		total_length = total_length + sizeof(guint8) + sizeof(guint32) + sizeof(guint8) + 
+			strlen(profile->username) + 1 + sizeof(guint8) + strlen(profile->password) + 1 + AES_SALT_LENGTH + 
+			sizeof(guint8) + strlen(profile->firstname) + 1 + sizeof(guint8) + strlen(profile->lastname) + 1 + 
+			sizeof(guint8) + strlen(profile->authlevel) + 1 + sizeof(guint16) + sizeof(guint32) + sizeof(guint32);
 	}
 	
 	if((all_profiles = (gchar*)g_try_malloc0(sizeof(gchar*)*total_length)) == NULL) return NULL;
@@ -356,6 +370,10 @@ gchar* gems_teacher_server_serialize_all_profiles(GList* list, guint* length)
 	{
 		profile = (jammo_profile_container*)iter->data;
 		
+		//type
+		*(guint8*)&all_profiles[position] = profile->type;
+		position++;
+		
 		// id
 		*(guint32*)&all_profiles[position] = profile->userid;
 		position = position + sizeof(guint32);
@@ -425,6 +443,7 @@ GList* gems_teacher_server_deserialize_profiles(GList* list, gchar* serialized_d
 {
 	jammo_profile_container* profile = NULL;
 	
+	guint8 type = 0;
 	guint32 id = 0;
 	gchar* username = NULL;
 	gchar* password = NULL;
@@ -441,6 +460,9 @@ GList* gems_teacher_server_deserialize_profiles(GList* list, gchar* serialized_d
 	
 	while(position < length)
 	{
+		type = *(guint8*)&serialized_data[position];
+		position++;
+		
 		// user id
 		id = *(guint32*)&serialized_data[position];
 		position = position + sizeof(guint32);
@@ -508,7 +530,7 @@ GList* gems_teacher_server_deserialize_profiles(GList* list, gchar* serialized_d
 		position = position + sizeof(guint32);
 		
 		// create profile and add to list
-		if((profile = gems_teacher_server_setup_profile(id,username,password,salt,authlevel,firstname,
+		if((profile = gems_teacher_server_setup_profile(type,id,username,password,salt,authlevel,firstname,
 			lastname,age,points,avatarid)) != NULL) list = g_list_append(list,profile);
 		
 		g_free(username);
@@ -782,7 +804,7 @@ gint gems_teacher_server_read_profile_database(teacher_server_profile_data** dat
 	{
 		rval = READ_FAIL_FILE_NOT_EXIST;
 	}
-  
+	
 	if(contents != NULL) g_free(contents);
 	if(filename != NULL) g_free(filename);
 
