@@ -281,7 +281,7 @@ gint gems_group_send_to_group(gems_message* msg)
 	if(data->service_group->group_info->own_state != IN_GROUP)
 	{
 		logmsg = g_strdup_printf("gems_group_send_to_group: not accepted to group, cannot send");
-		cem_add_to_log(logmsg,J_LOG_ERROR);
+		cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 		g_free(logmsg);
 		return -1;
 	}
@@ -297,16 +297,17 @@ gint gems_group_send_to_group(gems_message* msg)
 				// TODO change to use JAMMO_PACKET_GROUP
 				if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE, element, msg) == FALSE)
 				{
-					logmsg = g_strdup_printf("gems_group_send_to_group: cannot send group message to device %d user %d",
-						ph_c_connection_get_device_checksum(element->connection), data->service_group->group_info->peers[i]);
-					cem_add_to_log(logmsg,J_LOG_ERROR);
+					logmsg = g_strdup_printf("gems_group_send_to_group: cannot send group message to device %s/%u user %u",
+						ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection), 
+						data->service_group->group_info->peers[i]);
+					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 				}
 			}
 			else
 			{
-				logmsg = g_strdup_printf("gems_group_send_to_group: no connection to user %d", data->service_group->group_info->peers[i]);
-				cem_add_to_log(logmsg,J_LOG_ERROR);
+				logmsg = g_strdup_printf("gems_group_send_to_group: no connection to user %u", data->service_group->group_info->peers[i]);
+				cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
 			}
 		}
@@ -465,8 +466,9 @@ gint gems_group_join_to_group(guint32 gid)
 	
 	if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE,element,msg) == FALSE)
 	{
-		gchar* logmsg = g_strdup_printf("gems_group_join_to_group: cannot send JOIN_GROUP to group %d owner %d",gid, owner);
-		cem_add_to_log(logmsg,J_LOG_ERROR);
+		gchar* logmsg = g_strdup_printf("gems_group_join_to_group: cannot send JOIN_GROUP to group %u owner %u (%s/%u)", 
+			gid, owner, ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
+		cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 		g_free(logmsg);
 		gems_clear_message(msg);
 		return REQUEST_NOT_SENT;
@@ -479,6 +481,7 @@ gint gems_group_join_to_group(guint32 gid)
 		
 		print_group(data->service_group->group_info);
 		gems_clear_message(msg);
+		cem_add_to_log("Join request was succesfully sent.",J_LOG_NETWORK);
 		return REQUEST_SENT;
 	}
 }
@@ -508,6 +511,7 @@ gint gems_group_leave_from_group()
 		if(data->service_group->group_info->spaces == (data->service_group->group_info->size - 1))
 		{
 			gems_reset_group_info(data->service_group->group_info);
+			cem_add_to_log("Left from empty group as group owner.",J_LOG_INFO);
 			return REQUEST_SENT;
 		}
 		
@@ -536,6 +540,8 @@ gint gems_group_leave_from_group()
 		// Send to group members - they update the new owner
 		gems_group_send_to_group(msg);
 		
+		cem_add_to_log("Leaving as owner of the group, updated group info sent to other members",J_LOG_NETWORK);
+		
 		gems_clear_message(msg);
 	}
 	
@@ -548,9 +554,10 @@ gint gems_group_leave_from_group()
 	
 	if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE,element,msg) == FALSE)
 	{
-		gchar* logmsg = g_strdup_printf("gems_group_leave_from_group: cannot send LEAVE_GROUP to group %d owner %d",
-			data->service_group->group_info->owner, data->service_group->group_info->id);
-		cem_add_to_log(logmsg,J_LOG_ERROR);
+		gchar* logmsg = g_strdup_printf("gems_group_leave_from_group: cannot send LEAVE_GROUP to group %u owner %u (%s/%u)",
+			data->service_group->group_info->owner, data->service_group->group_info->id, ph_c_connection_get_remote_address(element->connection),
+			ph_c_connection_get_device_checksum(element->connection));
+		cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 		g_free(logmsg);
 		gems_clear_message(msg);
 		return REQUEST_NOT_SENT;
@@ -560,6 +567,7 @@ gint gems_group_leave_from_group()
 	{
 		data->service_group->group_info->own_state = LEAVING;
 		gems_clear_message(msg);
+		cem_add_to_log("Leave request was succesfully sent.",J_LOG_NETWORK);
 		return REQUEST_SENT;
 	}
 }
@@ -580,13 +588,16 @@ void gems_group_disconnected_member_detected(guint32 id)
 		gems_message* msg = gems_create_message_group_management_notify(MEMBER_DROPPED, info->id, id);
 		
 		// Notify other members
-		if(gems_group_send_to_group(msg) == 1) logmsg = g_strdup_printf("gems_group_disconnected_member: sent notification to group about disconnected member.\n");
-		else logmsg = g_strdup_printf("gems_group_disconnected_member: cannot send notification to group about disconnected member, not in group.\n");
+		if(gems_group_send_to_group(msg) == 1) logmsg = g_strdup_printf("gems_group_disconnected_member: sent notification to group about disconnected member: %u.",id);
+		else logmsg = g_strdup_printf("gems_group_disconnected_member: cannot send notification to group about disconnected member (%u), not in group.",id);
 	}
-	else logmsg = g_strdup_printf("gems_group_disconnected_member: sent notification to group about disconnected member\n");
+	else logmsg = g_strdup_printf("gems_group_disconnected_member: sent notification to group about disconnected member: %u.",id);
 	
-	if(logmsg != NULL) cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
-	g_free(logmsg);
+	if(logmsg)
+	{
+		cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
+		g_free(logmsg);
+	}
 }
 
 guint32 gems_group_get_gid(gems_group_info* group)
