@@ -764,9 +764,9 @@ static void initialize_state(JammoSample* sample) {
 					     NULL);
 			}
 		}
-	} else {
-		g_free(filename);
 	}
+
+	g_free(filename);//this is coming from str_replace, which allocates memory for it
 }
 
 static void on_sequencer_notify(JammoSample* sample) {
