@@ -12,11 +12,13 @@
 #include "jammo-meam.h"
 #include "jammo-meam-private.h"
 #include "jammo-pipeline.h"
+#include "../cem/cem.h"
 
 #include <clutter/clutter.h>
 
 #define BUFFER_TIME 10000
 
+
 /**
  * SECTION:jammo-sequencer
  * @Short_description: A multitrack sequencer
@@ -341,7 +343,7 @@ void jammo_sequencer_add_track(JammoSequencer* sequencer, JammoTrack* track) {
 	GstElement* element;
 	
 	if (g_list_find(sequencer->priv->tracks, track)) {
-		g_warning("A track is already added into a sequencer.");
+		cem_add_to_log("A track is already added into a sequencer.",J_LOG_WARN);
 	} else {
 		sequencer->priv->tracks = g_list_prepend(sequencer->priv->tracks, g_object_ref_sink(track));
 		_jammo_track_set_tempo(track, sequencer->priv->tempo);
@@ -358,7 +360,7 @@ void jammo_sequencer_add_track(JammoSequencer* sequencer, JammoTrack* track) {
 			/* Dirty fix: We know that the track is JammoRecordingTrack. Singing game requires
 			 * addition buffers in order to work decently in Nokia N900, which has latency isses.
 			 */
-			g_print("Added some buffers into pulse sink to help recording.\n");
+			cem_add_to_log("Added some buffers into pulse sink to help recording.", J_LOG_DEBUG);
 			g_object_set(G_OBJECT(sequencer->priv->audiosink), "buffer-time", (gint64)80000, NULL);
 		}
 
@@ -757,18 +759,25 @@ static gboolean jammo_sequencer_parse_custom_node(ClutterScriptable* scriptable,
 	gint i;
 	JsonNode* n;
 	GObject* object;
-	
+	gchar* message;
+
 	if (!g_strcmp0(name, "tracks")) {
 		if (JSON_NODE_TYPE(node) != JSON_NODE_ARRAY) {
-			g_warning("Expected JSON array for '%s', skipped.", name);
+				message = g_strdup_printf("Expected JSON array for '%s', skipped.", name);
+				cem_add_to_log(message,J_LOG_WARN);
+				g_free(message);
 		} else {
 			array = json_node_get_array(node);
 			for (i = json_array_get_length(array) - 1; i >= 0; i--) {
 				n = json_array_get_element(array, i);
 				if (JSON_NODE_TYPE(n) != JSON_NODE_VALUE || json_node_get_value_type(n) != G_TYPE_STRING) {
-					g_warning("Expected a string value in '%s' array, skipped.", name);
+					message = g_strdup_printf("Expected a string value in '%s' array, skipped.", name);
+					cem_add_to_log(message,J_LOG_WARN);
+					g_free(message);
 				} else if (!(object = clutter_script_get_object(script, json_node_get_string(n)))) {
-					g_warning("A reference to non-existing object '%s' in '%s' array, skipped.", json_node_get_string(n), name);
+					message = g_strdup_printf("A reference to non-existing object '%s' in '%s' array, skipped.", json_node_get_string(n), name);
+					cem_add_to_log(message,J_LOG_WARN);
+					g_free(message);
 				} else {
 					slist = g_slist_prepend(slist, object);
 				}
@@ -835,7 +844,7 @@ static gboolean on_bus_message(GstBus* bus, GstMessage* message, gpointer data)
 			break;
 		case GST_MESSAGE_ERROR:
 			gst_message_parse_error(message, &error, &debug);
-			g_print("Error: %s\n", error->message);
+			cem_add_to_log(error->message,J_LOG_ERROR);
 			g_error_free(error);
 			g_free(debug);
 			break;
